pkgsrc-Changes archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
CVS commit: pkgsrc/lang/rust
Module Name: pkgsrc
Committed By: he
Date: Sun Feb 23 08:53:55 UTC 2025
Modified Files:
pkgsrc/lang/rust: Makefile buildlink3.mk distinfo options.mk
platform.mk
pkgsrc/lang/rust/patches: patch-compiler_rustc__llvm_build.rs
patch-compiler_rustc__target_src_spec_base_netbsd.rs
patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs
patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs
patch-src_bootstrap_bootstrap.py
patch-src_bootstrap_src_core_builder.rs
patch-src_bootstrap_src_lib.rs
patch-src_tools_cargo_tests_testsuite_build.rs
patch-vendor_bytecount-0.6.8_src_lib.rs
Added Files:
pkgsrc/lang/rust/patches: patch-tests_assembly_targets_targets-elf.rs
Removed Files:
pkgsrc/lang/rust/patches: patch-config.example.toml
patch-src_bootstrap_src_core_build__steps_dist.rs
patch-src_bootstrap_src_core_config_config.rs
patch-vendor_cc-1.0.73_src_lib.rs
Log Message:
lang/rust: update to version 1.83.0 from pkgsrc-wip.
Pkgsrc changes:
* Introduce use of TOOL* settings.
* On NetBSD, use patchelf in the install phase to fix up RPATHs.
* Reduce verbosity by dropping -v flag to x.py invocations.
* Remove patches related to https://github.com/rust-lang/rust/pull/130110/,
which is now integrated upstream.
* Remove patch to vendor/cc-1.0.79, now integrated in the current
vendored cc crate.
* Checksum updates.
Upstream changes:
Version 1.83.0 (2024-11-28)
==========================
Language
--------
- [Stabilize `&mut`, `*mut`, `&Cell`, and `*const Cell` in const.]
(https://github.com/rust-lang/rust/pull/129195)
- [Allow creating references to statics in `const` initializers.]
(https://github.com/rust-lang/rust/pull/129759)
- [Implement raw lifetimes and labels (`'r#ident`).]
(https://github.com/rust-lang/rust/pull/126452)
- [Define behavior when atomic and non-atomic reads race.]
(https://github.com/rust-lang/rust/pull/128778)
- [Non-exhaustive structs may now be empty.]
(https://github.com/rust-lang/rust/pull/128934)
- [Disallow implicit coercions from places of type `!`]
(https://github.com/rust-lang/rust/pull/129392)
- [`const extern` functions can now be defined for other calling conventions.]
(https://github.com/rust-lang/rust/pull/129753)
- [Stabilize `expr_2021` macro fragment specifier in all editions.]
(https://github.com/rust-lang/rust/pull/129972)
- [The `non_local_definitions` lint now fires on less code and
warns by default.]
(https://github.com/rust-lang/rust/pull/127117)
Compiler
--------
- [Deprecate unsound `-Csoft-float` flag.]
(https://github.com/rust-lang/rust/pull/129897)
- Add many new tier 3 targets:
- [`aarch64_unknown_nto_qnx700`]
(https://github.com/rust-lang/rust/pull/127897)
- [`arm64e-apple-tvos`]
(https://github.com/rust-lang/rust/pull/130614)
- [`armv7-rtems-eabihf`]
(https://github.com/rust-lang/rust/pull/127021)
- [`loongarch64-unknown-linux-ohos`]
(https://github.com/rust-lang/rust/pull/130750)
- [`riscv32-wrs-vxworks` and `riscv64-wrs-vxworks`]
(https://github.com/rust-lang/rust/pull/130549)
- [`riscv32{e|em|emc}-unknown-none-elf`]
(https://github.com/rust-lang/rust/pull/130555)
- [`x86_64-unknown-hurd-gnu`]
(https://github.com/rust-lang/rust/pull/128345)
- [`x86_64-unknown-trusty`]
(https://github.com/rust-lang/rust/pull/130453)
Refer to Rust's [platform support page][platform-support-doc]
for more information on Rust's tiered platform support.
Libraries
---------
- [Implement `PartialEq` for `ExitCode`.]
(https://github.com/rust-lang/rust/pull/127633)
- [Document that `catch_unwind` can deal with foreign exceptions
without UB, although the exact behavior is unspecified.]
(https://github.com/rust-lang/rust/pull/128321)
- [Implement `Default` for `HashMap`/`HashSet` iterators that don't
already have it.]
(https://github.com/rust-lang/rust/pull/128711)
- [Bump Unicode to version 16.0.0.]
(https://github.com/rust-lang/rust/pull/130183)
- [Change documentation of `ptr::add`/`sub` to not claim equivalence
with `offset`.]
(https://github.com/rust-lang/rust/pull/130229).
Stabilized APIs
---------------
- [`BufRead::skip_until`]
(https://doc.rust-lang.org/stable/std/io/trait.BufRead.html#method.skip_until)
- [`ControlFlow::break_value`]
(https://doc.rust-lang.org/stable/core/ops/enum.ControlFlow.html#method.break_value)
- [`ControlFlow::continue_value`]
(https://doc.rust-lang.org/stable/core/ops/enum.ControlFlow.html#method.continue_value)
- [`ControlFlow::map_break`]
(https://doc.rust-lang.org/stable/core/ops/enum.ControlFlow.html#method.map_break)
- [`ControlFlow::map_continue`]
(https://doc.rust-lang.org/stable/core/ops/enum.ControlFlow.html#method.map_continue)
- [`DebugList::finish_non_exhaustive`]
(https://doc.rust-lang.org/stable/core/fmt/struct.DebugList.html#method.finish_non_exhaustive)
- [`DebugMap::finish_non_exhaustive`]
(https://doc.rust-lang.org/stable/core/fmt/struct.DebugMap.html#method.finish_non_exhaustive)
- [`DebugSet::finish_non_exhaustive`]
(https://doc.rust-lang.org/stable/core/fmt/struct.DebugSet.html#method.finish_non_exhaustive)
- [`DebugTuple::finish_non_exhaustive`]
(https://doc.rust-lang.org/stable/core/fmt/struct.DebugTuple.html#method.finish_non_exhaustive)
- [`ErrorKind::ArgumentListTooLong`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.ArgumentListTooLong)
- [`ErrorKind::Deadlock`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.Deadlock)
- [`ErrorKind::DirectoryNotEmpty`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.DirectoryNotEmpty)
- [`ErrorKind::ExecutableFileBusy`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.ExecutableFileBusy)
- [`ErrorKind::FileTooLarge`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.FileTooLarge)
- [`ErrorKind::HostUnreachable`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.HostUnreachable)
- [`ErrorKind::IsADirectory`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.IsADirectory)
- [`ErrorKind::NetworkDown`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.NetworkDown)
- [`ErrorKind::NetworkUnreachable`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.NetworkUnreachable)
- [`ErrorKind::NotADirectory`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.NotADirectory)
- [`ErrorKind::NotSeekable`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.NotSeekable)
- [`ErrorKind::ReadOnlyFilesystem`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.ReadOnlyFilesystem)
- [`ErrorKind::ResourceBusy`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.ResourceBusy)
- [`ErrorKind::StaleNetworkFileHandle`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.StaleNetworkFileHandle)
- [`ErrorKind::StorageFull`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.StorageFull)
- [`ErrorKind::TooManyLinks`]
(https://doc.rust-lang.org/stable/std/io/enum.ErrorKind.html#variant.TooManyLinks)
- [`Option::get_or_insert_default`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.get_or_insert_default)
- [`Waker::data`]
(https://doc.rust-lang.org/stable/core/task/struct.Waker.html#method.data)
- [`Waker::new`]
(https://doc.rust-lang.org/stable/core/task/struct.Waker.html#method.new)
- [`Waker::vtable`]
(https://doc.rust-lang.org/stable/core/task/struct.Waker.html#method.vtable)
- [`char::MIN`]
(https://doc.rust-lang.org/stable/core/primitive.char.html#associatedconstant.MIN)
- [`hash_map::Entry::insert_entry`]
(https://doc.rust-lang.org/stable/std/collections/hash_map/enum.Entry.html#method.insert_entry)
- [`hash_map::VacantEntry::insert_entry`]
(https://doc.rust-lang.org/stable/std/collections/hash_map/struct.VacantEntry.html#method.insert_entry)
These APIs are now stable in const contexts:
- [`Cell::into_inner`]
(https://doc.rust-lang.org/stable/core/cell/struct.Cell.html#method.into_inner)
- [`Duration::as_secs_f32`]
(https://doc.rust-lang.org/stable/core/time/struct.Duration.html#method.as_secs_f32)
- [`Duration::as_secs_f64`]
(https://doc.rust-lang.org/stable/core/time/struct.Duration.html#method.as_secs_f64)
- [`Duration::div_duration_f32`]
(https://doc.rust-lang.org/stable/core/time/struct.Duration.html#method.div_duration_f32)
- [`Duration::div_duration_f64`]
(https://doc.rust-lang.org/stable/core/time/struct.Duration.html#method.div_duration_f64)
- [`MaybeUninit::as_mut_ptr`]
(https://doc.rust-lang.org/stable/core/mem/union.MaybeUninit.html#method.as_mut_ptr)
- [`NonNull::as_mut`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.as_mut)
- [`NonNull::copy_from`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.copy_from)
- [`NonNull::copy_from_nonoverlapping`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.copy_from_nonoverlapping)
- [`NonNull::copy_to`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.copy_to)
- [`NonNull::copy_to_nonoverlapping`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.copy_to_nonoverlapping)
- [`NonNull::slice_from_raw_parts`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.slice_from_raw_parts)
- [`NonNull::write`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.write)
- [`NonNull::write_bytes`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.write_bytes)
- [`NonNull::write_unaligned`]
(https://doc.rust-lang.org/stable/core/ptr/struct.NonNull.html#method.write_unaligned)
- [`OnceCell::into_inner`]
(https://doc.rust-lang.org/stable/core/cell/struct.OnceCell.html#method.into_inner)
- [`Option::as_mut`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.as_mut)
- [`Option::expect`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.expect)
- [`Option::replace`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.replace)
- [`Option::take`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.take)
- [`Option::unwrap`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.unwrap)
- [`Option::unwrap_unchecked`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.unwrap_unchecked)
- [`Option::<&_>::copied`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.copied)
- [`Option::<&mut _>::copied`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.copied-1)
- [`Option::<Option<_>>::flatten`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.flatten)
- [`Option::<Result<_, _>>::transpose`]
(https://doc.rust-lang.org/stable/core/option/enum.Option.html#method.transpose)
- [`RefCell::into_inner`]
(https://doc.rust-lang.org/stable/core/cell/struct.RefCell.html#method.into_inner)
- [`Result::as_mut`]
(https://doc.rust-lang.org/stable/core/result/enum.Result.html#method.as_mut)
- [`Result::<&_, _>::copied`]
(https://doc.rust-lang.org/stable/core/result/enum.Result.html#method.copied)
- [`Result::<&mut _, _>::copied`]
(https://doc.rust-lang.org/stable/core/result/enum.Result.html#method.copied-1)
- [`Result::<Option<_>, _>::transpose`]
(https://doc.rust-lang.org/stable/core/result/enum.Result.html#method.transpose)
- [`UnsafeCell::get_mut`]
(https://doc.rust-lang.org/stable/core/cell/struct.UnsafeCell.html#method.get_mut)
- [`UnsafeCell::into_inner`]
(https://doc.rust-lang.org/stable/core/cell/struct.UnsafeCell.html#method.into_inner)
- [`array::from_mut`]
(https://doc.rust-lang.org/stable/core/array/fn.from_mut.html)
- [`char::encode_utf8`]
(https://doc.rust-lang.org/stable/core/primitive.char.html#method.encode_utf8)
- [`{float}::classify`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.classify)
- [`{float}::is_finite`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_finite)
- [`{float}::is_infinite`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_infinite)
- [`{float}::is_nan`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_nan)
- [`{float}::is_normal`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_normal)
- [`{float}::is_sign_negative`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_sign_negative)
- [`{float}::is_sign_positive`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_sign_positive)
- [`{float}::is_subnormal`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.is_subnormal)
- [`{float}::from_bits`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.from_bits)
- [`{float}::from_be_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.from_be_bytes)
- [`{float}::from_le_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.from_le_bytes)
- [`{float}::from_ne_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.from_ne_bytes)
- [`{float}::to_bits`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.to_bits)
- [`{float}::to_be_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.to_be_bytes)
- [`{float}::to_le_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.to_le_bytes)
- [`{float}::to_ne_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.f64.html#method.to_ne_bytes)
- [`mem::replace`]
(https://doc.rust-lang.org/stable/core/mem/fn.replace.html)
- [`ptr::replace`]
(https://doc.rust-lang.org/stable/core/ptr/fn.replace.html)
- [`ptr::slice_from_raw_parts_mut`]
(https://doc.rust-lang.org/stable/core/ptr/fn.slice_from_raw_parts_mut.html)
- [`ptr::write`]
(https://doc.rust-lang.org/stable/core/ptr/fn.write.html)
- [`ptr::write_unaligned`]
(https://doc.rust-lang.org/stable/core/ptr/fn.write_unaligned.html)
- [`<*const _>::copy_to`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.copy_to)
- [`<*const _>::copy_to_nonoverlapping`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.copy_to_nonoverlapping)
- [`<*mut _>::copy_from`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.copy_from)
- [`<*mut _>::copy_from_nonoverlapping`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.copy_from_nonoverlapping)
- [`<*mut _>::copy_to`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.copy_to-1)
- [`<*mut _>::copy_to_nonoverlapping`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.copy_to_nonoverlapping-1)
- [`<*mut _>::write`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.write)
- [`<*mut _>::write_bytes`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.write_bytes)
- [`<*mut _>::write_unaligned`]
(https://doc.rust-lang.org/stable/core/primitive.pointer.html#method.write_unaligned)
- [`slice::from_mut`]
(https://doc.rust-lang.org/stable/core/slice/fn.from_mut.html)
- [`slice::from_raw_parts_mut`]
(https://doc.rust-lang.org/stable/core/slice/fn.from_raw_parts_mut.html)
- [`<[_]>::first_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.first_mut)
- [`<[_]>::last_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.last_mut)
- [`<[_]>::first_chunk_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.first_chunk_mut)
- [`<[_]>::last_chunk_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.last_chunk_mut)
- [`<[_]>::split_at_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_at_mut)
- [`<[_]>::split_at_mut_checked`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_at_mut_checked)
- [`<[_]>::split_at_mut_unchecked`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_at_mut_unchecked)
- [`<[_]>::split_first_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_first_mut)
- [`<[_]>::split_last_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_last_mut)
- [`<[_]>::split_first_chunk_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_first_chunk_mut)
- [`<[_]>::split_last_chunk_mut`]
(https://doc.rust-lang.org/stable/core/primitive.slice.html#method.split_last_chunk_mut)
- [`str::as_bytes_mut`]
(https://doc.rust-lang.org/stable/core/primitive.str.html#method.as_bytes_mut)
- [`str::as_mut_ptr`]
(https://doc.rust-lang.org/stable/core/primitive.str.html#method.as_mut_ptr)
- [`str::from_utf8_unchecked_mut`]
(https://doc.rust-lang.org/stable/core/str/fn.from_utf8_unchecked_mut.html)
Cargo
-----
- [Introduced a new `CARGO_MANIFEST_PATH` environment variable,
similar to `CARGO_MANIFEST_DIR` but pointing directly to the manifest
file.]
(https://github.com/rust-lang/cargo/pull/14404/)
- [Added `package.autolib` to the manifest, allowing `[lib]`
auto-discovery to be disabled.]
(https://github.com/rust-lang/cargo/pull/14591/)
- [Declare support level for each crate in Cargo's Charter / crate docs.]
(https://github.com/rust-lang/cargo/pull/14600/)
- [Declare new Intentional Artifacts as 'small' changes.]
(https://github.com/rust-lang/cargo/pull/14599/)
Rustdoc
-------
- [The sidebar / hamburger menu table of contents now includes the
`# headers` from the main item's doc comment]
(https://github.com/rust-lang/rust/pull/120736). This is similar
to a third-party feature provided by the rustdoc-search-enhancements
browser extension.
Compatibility Notes
-------------------
- [Warn against function pointers using unsupported ABI strings.]
(https://github.com/rust-lang/rust/pull/128784)
- [Check well-formedness of the source type's signature in fn
pointer casts.]
(https://github.com/rust-lang/rust/pull/129021) This partly closes
a soundness hole that comes when casting a function item to
function pointer
- [Use equality instead of subtyping when resolving type dependent paths.]
(https://github.com/rust-lang/rust/pull/129073)
- Linking on macOS now correctly includes Rust's default deployment
target. Due to a linker bug, you might have to pass
`MACOSX_DEPLOYMENT_TARGET` or fix your `#[link]` attributes to
point to the correct frameworks. See
<https://github.com/rust-lang/rust/pull/129369>.
- [Rust will now correctly raise an error for `repr(Rust)` written
on non-`struct`/`enum`/`union` items, since it previous did not
have any effect.]
(https://github.com/rust-lang/rust/pull/129422)
- The future incompatibility lint `deprecated_cfg_attr_crate_type_name`
[has been made into a hard error]
(https://github.com/rust-lang/rust/pull/129670). It was used to
deny usage of `#![crate_type]` and `#![crate_name]` attributes in
`#![cfg_attr]`, which required a hack in the compiler to be able
to change the used crate type and crate name after cfg expansion.
Users can use `--crate-type` instead of `#![cfg_attr(..., crate_type
= "...")]` and `--crate-name` instead of `#![cfg_attr(...,
crate_name = "...")]` when running `rustc`/`cargo rustc` on the
command line. Use of those two attributes outside of `#![cfg_attr]`
continue to be fully supported.
- Until now, paths into the sysroot were always prefixed with
`/rustc/$hash` in diagnostics, codegen, backtrace, e.g.
```
thread 'main' panicked at 'hello world', map-panic.rs:2:50
stack backtrace:
0: std::panicking::begin_panic
at /rustc/a55dd71d5fb0ec5a6a3a9e8c27b2127ba491ce52/library/std/src/panicking.rs:616:12
1: map_panic::main::{{closure}}
at ./map-panic.rs:2:50
2: core::option::Option<T>::map
at /rustc/a55dd71d5fb0ec5a6a3a9e8c27b2127ba491ce52/library/core/src/option.rs:929:29
3: map_panic::main
at ./map-panic.rs:2:30
4: core::ops::function::FnOnce::call_once
at /rustc/a55dd71d5fb0ec5a6a3a9e8c27b2127ba491ce52/library/core/src/ops/function.rs:248:5
note: Some details are omitted, run with `RUST_BACKTRACE=full` for a verbose backtrace.
```
[RFC 3127 said]
(https://rust-lang.github.io/rfcs/3127-trim-paths.html#changing-handling-of-sysroot-path-in-rustc)
> We want to change this behaviour such that, when `rust-src`
source files can be discovered, the virtual path is discarded
and therefore the local path will be embedded, unless there is
a `--remap-path-prefix` that causes this local path to be remapped
in the usual way.
[#129687](https://github.com/rust-lang/rust/pull/129687)
implements this behaviour, when `rust-src` is present at compile
time, `rustc` replaces `/rustc/$hash` with a real path into
the local `rust-src` component with best effort. To sanitize
this, users must explicitly supply `--remap-path-prefix=<path
to rust-src>=foo` or not have the `rust-src` component installed.
- The allow-by-default `missing_docs` lint used to disable itself
when invoked through `rustc --test`/`cargo test`, resulting in
`#[expect(missing_docs)]` emitting false positives due to the
expectation being wrongly unfulfilled. This behavior [has now been
removed]
(https://github.com/rust-lang/rust/pull/130025), which allows
`#[expect(missing_docs)]` to be fulfilled in all scenarios, but
will also report new `missing_docs` diagnostics for publicly
reachable `#[cfg(test)]` items, [integration test]
(https://doc.rust-lang.org/cargo/reference/cargo-targets.html#integration-tests)
crate-level documentation, and publicly reachable items in
integration tests.
- [The `armv8r-none-eabihf` target now uses the Armv8-R required
set of floating-point features.]
(https://github.com/rust-lang/rust/pull/130295)
- [Fix a soundness bug where rustc wouldn't detect unconstrained
higher-ranked lifetimes in a `dyn Trait`'s associated types that
occur due to supertraits.]
(https://github.com/rust-lang/rust/pull/130367)
- [Update the minimum external LLVM version to 18.]
(https://github.com/rust-lang/rust/pull/130487)
- [Remove `aarch64-fuchsia` and `x86_64-fuchsia` target aliases in
favor of `aarch64-unknown-fuchsia` and `x86_64-unknown-fuchsia`
respectively.]
(https://github.com/rust-lang/rust/pull/130657)
- [The ABI-level exception class of a Rust panic is now encoded
with native-endian bytes, so it is legible in hex dumps.]
(https://github.com/rust-lang/rust/pull/130897)
- [Visual Studio 2013 is no longer supported for MSVC targets.]
(https://github.com/rust-lang/rust/pull/131070)
- [The sysroot no longer contains the `std` dynamic library in its
top-level `lib/` dir.]
(https://github.com/rust-lang/rust/pull/131188)
To generate a diff of this commit:
cvs rdiff -u -r1.323 -r1.324 pkgsrc/lang/rust/Makefile
cvs rdiff -u -r1.14 -r1.15 pkgsrc/lang/rust/buildlink3.mk
cvs rdiff -u -r1.178 -r1.179 pkgsrc/lang/rust/distinfo
cvs rdiff -u -r1.42 -r1.43 pkgsrc/lang/rust/options.mk
cvs rdiff -u -r1.29 -r1.30 pkgsrc/lang/rust/platform.mk
cvs rdiff -u -r1.17 -r1.18 \
pkgsrc/lang/rust/patches/patch-compiler_rustc__llvm_build.rs
cvs rdiff -u -r1.3 -r1.4 \
pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_base_netbsd.rs \
pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs
cvs rdiff -u -r1.1 -r1.2 \
pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs \
pkgsrc/lang/rust/patches/patch-vendor_bytecount-0.6.8_src_lib.rs
cvs rdiff -u -r1.1 -r0 pkgsrc/lang/rust/patches/patch-config.example.toml \
pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_config_config.rs
cvs rdiff -u -r1.24 -r1.25 \
pkgsrc/lang/rust/patches/patch-src_bootstrap_bootstrap.py
cvs rdiff -u -r1.2 -r0 \
pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_build__steps_dist.rs
cvs rdiff -u -r1.6 -r1.7 \
pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_builder.rs
cvs rdiff -u -r1.2 -r1.3 \
pkgsrc/lang/rust/patches/patch-src_bootstrap_src_lib.rs
cvs rdiff -u -r1.15 -r1.16 \
pkgsrc/lang/rust/patches/patch-src_tools_cargo_tests_testsuite_build.rs
cvs rdiff -u -r0 -r1.1 \
pkgsrc/lang/rust/patches/patch-tests_assembly_targets_targets-elf.rs
cvs rdiff -u -r1.5 -r0 \
pkgsrc/lang/rust/patches/patch-vendor_cc-1.0.73_src_lib.rs
Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Modified files:
Index: pkgsrc/lang/rust/Makefile
diff -u pkgsrc/lang/rust/Makefile:1.323 pkgsrc/lang/rust/Makefile:1.324
--- pkgsrc/lang/rust/Makefile:1.323 Thu Feb 6 13:34:44 2025
+++ pkgsrc/lang/rust/Makefile Sun Feb 23 08:53:54 2025
@@ -1,6 +1,6 @@
-# $NetBSD: Makefile,v 1.323 2025/02/06 13:34:44 riastradh Exp $
+# $NetBSD: Makefile,v 1.324 2025/02/23 08:53:54 he Exp $
-DISTNAME= rustc-1.82.0-src
+DISTNAME= rustc-1.83.0-src
PKGNAME= ${DISTNAME:S/rustc/rust/:S/-src//}
CATEGORIES= lang
MASTER_SITES= https://static.rust-lang.org/dist/
@@ -61,6 +61,7 @@ CONFIGURE_ARGS+= ${ADD_CONFIGURE_ARGS}
# uncommenting the LD_LIBRARY_PATH setting may be required to run
# the bootstrap
PKGSRC_MAKE_ENV+= LD_LIBRARY_PATH=${RUST_BOOTSTRAP_PATH:Q}/lib
+MAKE_ENV+= LD_LIBRARY_PATH=${RUST_BOOTSTRAP_PATH:Q}/lib
# This should allow us to perform "offline" builds (so cargo doesn't fetch
# dependencies during the build stage) but this isn't hooked up yet.
@@ -90,6 +91,11 @@ CHECK_SSP_SUPPORTED= no
.include "../../mk/bsd.prefs.mk"
+.if ${OPSYS} == "NetBSD"
+TOOL_DEPENDS+= patchelf-[0-9]*:../../devel/patchelf
+FORCE_RPATH= --force-rpath
+.endif
+
# Allow overriding MAKE_JOBS_SAFE
# some may chose to mostly build faster,
# and deal with any failures due to deadlocks
@@ -210,49 +216,49 @@ BUILDLINK_TRANSFORM+= opt:x86_64:arm64
DISTFILES:= ${DEFAULT_DISTFILES}
.if ${MACHINE_PLATFORM:MDarwin-*-aarch64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= aarch64-apple-darwin
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MDarwin-*-x86_64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= x86_64-apple-darwin
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MLinux-*-aarch64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= aarch64-unknown-linux-gnu
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MLinux-*-earmv6hf} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= arm-unknown-linux-gnueabihf
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MLinux-*-earmv7hf} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= armv7-unknown-linux-gnueabihf
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MLinux-*-i386} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= i686-unknown-linux-gnu
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MLinux-*-x86_64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= x86_64-unknown-linux-gnu
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
@@ -264,7 +270,7 @@ DISTFILES:= ${DISTFILES} ${RUST_STAGE0}
# x86_64-sun-solaris bootstrap and comment out the overrides.
#
.if ${MACHINE_PLATFORM:MSunOS-*-x86_64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= x86_64-unknown-illumos
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
SITES.${RUST_STAGE0}= https://us-central.manta.mnx.io/pkgsrc/public/pkg-bootstraps/
@@ -277,14 +283,14 @@ CONFIGURE_ARGS+= --host=${RUST_ARCH}
CONFIGURE_ARGS+= --target=${RUST_ARCH}
.endif
.if ${MACHINE_PLATFORM:MFreeBSD-*-x86_64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH:= x86_64-unknown-freebsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.gz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-i386} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH= i586-unknown-netbsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
@@ -304,14 +310,14 @@ pre-build-fix-paxctl:
${TOOLS_PLATFORM.paxctl} +am ${WRKDIR}/rust-bootstrap/bin/rustc
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-x86_64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH= x86_64-unknown-netbsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-powerpc} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH= powerpc-unknown-netbsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
@@ -320,7 +326,7 @@ SITES.${RUST_STAGE0}= ${MASTER_SITE_LOC
SITES.${RUST_STD_STAGE0}= ${MASTER_SITE_LOCAL:=rust/}
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-aarch64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH= aarch64-unknown-netbsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
@@ -329,7 +335,7 @@ SITES.${RUST_STAGE0}= ${MASTER_SITE_LOC
SITES.${RUST_STD_STAGE0}= ${MASTER_SITE_LOCAL:=rust/}
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-aarch64eb} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH= aarch64_be-unknown-netbsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
@@ -338,7 +344,7 @@ SITES.${RUST_STAGE0}= ${MASTER_SITE_LOC
SITES.${RUST_STD_STAGE0}= ${MASTER_SITE_LOCAL:=rust/}
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-sparc64} || make(distinfo) || make (makesum) || make(mdi)
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_ARCH= sparc64-unknown-netbsd
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
@@ -348,7 +354,7 @@ SITES.${RUST_STD_STAGE0}= ${MASTER_SITE_
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-earmv7hf} || make(distinfo) || make (makesum) || make(mdi)
RUST_ARCH= armv7-unknown-netbsd-eabihf
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
@@ -357,7 +363,7 @@ SITES.${RUST_STD_STAGE0}= ${MASTER_SITE_
.endif
.if ${MACHINE_PLATFORM:MNetBSD-*-earmv6hf} || make(distinfo) || make (makesum) || make(mdi)
RUST_ARCH= armv6-unknown-netbsd-eabihf
-RUST_STAGE0_VER= 1.81.0
+RUST_STAGE0_VER= 1.82.0
RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
@@ -366,7 +372,7 @@ SITES.${RUST_STD_STAGE0}= ${MASTER_SITE_
.endif
#.if ${MACHINE_PLATFORM:MNetBSD-*-mipsel} || make(distinfo) || make (makesum) || make(mdi)
#RUST_ARCH= mipsel-unknown-netbsd
-#RUST_STAGE0_VER= 1.81.0
+#RUST_STAGE0_VER= 1.82.0
#RUST_STAGE0:= rust-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
#RUST_STD_STAGE0:= rust-std-${RUST_STAGE0_VER}-${RUST_ARCH}.tar.xz
#DISTFILES:= ${DISTFILES} ${RUST_STAGE0} ${RUST_STD_STAGE0}
@@ -457,7 +463,7 @@ CKSUMS+= 27f9bff08b24828e1a611b10a0282f5
CKSUM_CRATES+= vendor/bytecount-0.6.8
CKSUMS+= 01cd755a128d8a5892f3edda195b26bb461be375be17dd72e6e4f061169e6dff
-CKSUMS+= a6750c0e2a6c385ec902cd7f87de7835fe2b4171b9c83da64122274ee20a77c6
+CKSUMS+= 7c6609685c161ac6b2c667f59bd6476c5c14c7269ec949fb2def5a0238198c25
SUBST_CLASSES+= cksum
SUBST_STAGE.cksum= pre-configure
@@ -543,11 +549,30 @@ do-test:
${SETENV} ${MAKE_ENV} \
${TOOL_PYTHONBIN} ./x.py test -j ${_MAKE_JOBS_N}
+PATCH_BINARIES+= bin/cargo
+PATCH_BINARIES+= bin/cargo-clippy
+PATCH_BINARIES+= bin/clippy-driver
+PATCH_BINARIES+= bin/rust-analyzer
+PATCH_BINARIES+= bin/rustc
+PATCH_BINARIES+= bin/rustdoc
+PATCH_BINARIES+= bin/rustfmt
+PATCH_BINARIES+= libexec/rust-analyzer-proc-macro-srv
+
do-install:
${RUN}${_ULIMIT_CMD} \
cd ${WRKSRC} && \
${SETENV} ${MAKE_ENV} ${INSTALL_ENV} \
${TOOL_PYTHONBIN} ./x.py install -j ${_MAKE_JOBS_N}
+.if ${OPSYS} == "NetBSD"
+ for bin in ${PATCH_BINARIES}; do \
+ f=${DESTDIR}${PREFIX}/$${bin}; \
+ if [ -f $$f ]; then \
+cmd="${PREFIX}/bin/patchelf ${FORCE_RPATH} --set-rpath ${PREFIX}/lib $$f"; \
+ echo $$cmd; \
+ $$cmd; \
+ fi; \
+ done
+.endif
SUBST_CLASSES+= destdir
SUBST_STAGE.destdir= post-install
Index: pkgsrc/lang/rust/buildlink3.mk
diff -u pkgsrc/lang/rust/buildlink3.mk:1.14 pkgsrc/lang/rust/buildlink3.mk:1.15
--- pkgsrc/lang/rust/buildlink3.mk:1.14 Wed Oct 25 05:50:43 2023
+++ pkgsrc/lang/rust/buildlink3.mk Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-# $NetBSD: buildlink3.mk,v 1.14 2023/10/25 05:50:43 pin Exp $
+# $NetBSD: buildlink3.mk,v 1.15 2025/02/23 08:53:54 he Exp $
BUILDLINK_TREE+= rust
@@ -10,7 +10,7 @@ BUILDLINK_TREE+= rust
RUST_BUILDLINK3_MK:=
BUILDLINK_API_DEPENDS.rust+= rust>=1.56.1
-BUILDLINK_PKGSRCDIR.rust?= ../../lang/rust
+BUILDLINK_PKGSRCDIR.rust?= ../../wip/rust
BUILDLINK_PASSTHRU_DIRS+= ${PREFIX}/lib/rustlib
.endif
Index: pkgsrc/lang/rust/distinfo
diff -u pkgsrc/lang/rust/distinfo:1.178 pkgsrc/lang/rust/distinfo:1.179
--- pkgsrc/lang/rust/distinfo:1.178 Sun Feb 2 13:34:47 2025
+++ pkgsrc/lang/rust/distinfo Sun Feb 23 08:53:54 2025
@@ -1,145 +1,142 @@
-$NetBSD: distinfo,v 1.178 2025/02/02 13:34:47 he Exp $
+$NetBSD: distinfo,v 1.179 2025/02/23 08:53:54 he Exp $
-BLAKE2s (rust-1.81.0-aarch64-apple-darwin.tar.gz) = aa033b8af1b7cf6a08476da3f74fa4634bc82224fb170cda4683aa6b5fde0916
-SHA512 (rust-1.81.0-aarch64-apple-darwin.tar.gz) = 542be316f94beaf12d2c87f67acaaf41273a7fe2117768a46d02cef30522dd1c1fd4eeff22e516b77d5b173a435ff4140433b23327561318fbe4a0b1519f2ab9
-Size (rust-1.81.0-aarch64-apple-darwin.tar.gz) = 342382518 bytes
-BLAKE2s (rust-1.81.0-aarch64-unknown-linux-gnu.tar.gz) = 39c710c66162a654ca5fe27e651c43d753a2cf5be09ab259f985195a4b7a4949
-SHA512 (rust-1.81.0-aarch64-unknown-linux-gnu.tar.gz) = 456ea7e345ad856e27c0fa94b1e3c642eeb34cbfe6ffd34cc67622ce222ab17259913c329ee59a91b69b52bf447a85fc4c3141898080961a9de4094b4e1a17dd
-Size (rust-1.81.0-aarch64-unknown-linux-gnu.tar.gz) = 488236376 bytes
-BLAKE2s (rust-1.81.0-aarch64-unknown-netbsd.tar.xz) = d06db0dad290d162959052e44d6cb609c36a2851f92dc8aaad1b4ae08b3fa458
-SHA512 (rust-1.81.0-aarch64-unknown-netbsd.tar.xz) = 5517e60c488998f0ad18080e52850510100263bd92d8e9f8254742f75bf1a774d46e5c9bddfcfc185fcd51bafe59f24a24d38b1347ef599398e29f3147c66d60
-Size (rust-1.81.0-aarch64-unknown-netbsd.tar.xz) = 199857236 bytes
-BLAKE2s (rust-1.81.0-aarch64_be-unknown-netbsd.tar.xz) = f90a8038a4931ab11682f5ab93224702d4f4ef6583ef57ebca3ff596a0abdee3
-SHA512 (rust-1.81.0-aarch64_be-unknown-netbsd.tar.xz) = 1047c5f32c9a0ad5480238dc4c1c61061030639bdcb1e7853cb4401ad3ff5b9bca45d2d042aba040b2f86504835caddfc6c8eb4c60c6b023847ebcebd1578e21
-Size (rust-1.81.0-aarch64_be-unknown-netbsd.tar.xz) = 198057028 bytes
-BLAKE2s (rust-1.81.0-arm-unknown-linux-gnueabihf.tar.gz) = 9b503d5b2a2428a7f6657202b042f3655f859791585c55a80e0ed7c369f5ba6d
-SHA512 (rust-1.81.0-arm-unknown-linux-gnueabihf.tar.gz) = 0e9719f2b72e25eae21a7d34c3c5cdd655646b5fcacc4427e4c45db4e40f9d53db82bb631e4807984b280f31dfe90f81637fe32e72536f0b01e92b923fb637aa
-Size (rust-1.81.0-arm-unknown-linux-gnueabihf.tar.gz) = 372178843 bytes
-BLAKE2s (rust-1.81.0-armv6-unknown-netbsd-eabihf.tar.xz) = de41c01933b7016c83caab00d9105b5bb46996fec037d5b8f8f0caee856d44eb
-SHA512 (rust-1.81.0-armv6-unknown-netbsd-eabihf.tar.xz) = 9e2f0ea2852409e12c9ea0b8ed69d3ca2d50e06fd4879511a680c57ceefc8e2c038bff73538a7cd1547dcb71944d69383137ce3df5aa890504df18c117aa59ad
-Size (rust-1.81.0-armv6-unknown-netbsd-eabihf.tar.xz) = 169411036 bytes
-BLAKE2s (rust-1.81.0-armv7-unknown-linux-gnueabihf.tar.gz) = 615f19c752bc9db052e282e11b344137ced86ada54b918aea0e844ad321f3520
-SHA512 (rust-1.81.0-armv7-unknown-linux-gnueabihf.tar.gz) = 1fbfcdf94e48047ee7d6fa2553ae5adc7d2257fdbfdebf0a5379b856e75ea04d49c5f49f4d694324bcd66166d64849d46c302279bda7ba31ce4bff20f0de4d65
-Size (rust-1.81.0-armv7-unknown-linux-gnueabihf.tar.gz) = 360463528 bytes
-BLAKE2s (rust-1.81.0-armv7-unknown-netbsd-eabihf.tar.xz) = 49e09d97f2adb9161d10ac38df4e2f02ba5d99866aa1ead5090099a18ae6f02b
-SHA512 (rust-1.81.0-armv7-unknown-netbsd-eabihf.tar.xz) = de7a5c8746f941efce91fc82dd3775bf9e00b831581a201808b6baef061da8d1592ed91fdf0e29ba86feac6843f51c6ab105bae0079be9a72fcdc10d7494ef2a
-Size (rust-1.81.0-armv7-unknown-netbsd-eabihf.tar.xz) = 171194260 bytes
-BLAKE2s (rust-1.81.0-i586-unknown-netbsd.tar.xz) = 10ebe3f58b5cd33bd16eb5ef00e34759abf446d2b7c3ec044a9f66e070c8b28c
-SHA512 (rust-1.81.0-i586-unknown-netbsd.tar.xz) = 771ad395071b89e1c6163bdb75bfe3e8a62c009046e525c49b83aa29b732f7627571cc6c10104cc489cc805518a232095714f032a8e10726c990657d4ffbfa21
-Size (rust-1.81.0-i586-unknown-netbsd.tar.xz) = 217261872 bytes
-BLAKE2s (rust-1.81.0-i686-unknown-linux-gnu.tar.gz) = 831e8265e0a81a18c33482a04ab4ccf3aa376d44e63ff61c2d817cee36a430ff
-SHA512 (rust-1.81.0-i686-unknown-linux-gnu.tar.gz) = 7ca73bdf5393b57700c9273df99b02fc59c0cbb8e08dea29da8ed2e9f6816eafdc427202c4aa42fbd155dd138ec39106fe9a8502129fefecbd47a37d769af343
-Size (rust-1.81.0-i686-unknown-linux-gnu.tar.gz) = 439375569 bytes
-BLAKE2s (rust-1.81.0-powerpc-unknown-netbsd.tar.xz) = 70f5e9e8afd218b7d6421970d8b767aedb4c40cb0d4f57b0ff73bfdbcd21e7ac
-SHA512 (rust-1.81.0-powerpc-unknown-netbsd.tar.xz) = 2ac0493a5ae06525628b5655731fd18b9d1bb3f6bd483e603413ee63ac6b5dfbc26f6f16905cf0e3502a04170644802a4f66dee1c6a42409b03a4b0ee8274bb8
-Size (rust-1.81.0-powerpc-unknown-netbsd.tar.xz) = 230224080 bytes
-BLAKE2s (rust-1.81.0-sparc64-unknown-netbsd.tar.xz) = 6dd09b88f3de7e71f580c75f81da5bebb31a19d1e111806f0d984507c6ee65a1
-SHA512 (rust-1.81.0-sparc64-unknown-netbsd.tar.xz) = 3799752690ad0a0c80000ca284c8198fe8db46757f579e697dc77a0183ed7360d46355917dbed4c37dcc8debd55e7ee842d851054128b7e4ad4bee466ab3b788
-Size (rust-1.81.0-sparc64-unknown-netbsd.tar.xz) = 193855168 bytes
-BLAKE2s (rust-1.81.0-x86_64-apple-darwin.tar.gz) = 3ce64f23c508cc24929b0bd9d96e338a0fa2e6924cf7cefbb6cb9aace13b989e
-SHA512 (rust-1.81.0-x86_64-apple-darwin.tar.gz) = 06acf3a19beae8166622830d79799be61d80b8864e83aabe7a7b6e852d4e6ad0af9cb74278b6d703b8378739d8ed49e42cf771d75ef6789726fc491dd9ce35e1
-Size (rust-1.81.0-x86_64-apple-darwin.tar.gz) = 346755530 bytes
-BLAKE2s (rust-1.81.0-x86_64-unknown-freebsd.tar.gz) = ea20d7a67bed2b1a37b8ad31f92e121a2110f02311888b85cf0a03ec6320723b
-SHA512 (rust-1.81.0-x86_64-unknown-freebsd.tar.gz) = 3617c5054f0f8f6657c5cae0dfc49644cb83a28b1741bafb916f16d6681ef3697f09a0f892e24b629b720206ac4eda31fa7618ea647ab4dc29f31dd024dfb3dc
-Size (rust-1.81.0-x86_64-unknown-freebsd.tar.gz) = 329217094 bytes
-BLAKE2s (rust-1.81.0-x86_64-unknown-illumos.tar.gz) = 887706a94ceaf9fcae2c192545bc09c77d23d95b956d76d8cf6b2c1aaeffa203
-SHA512 (rust-1.81.0-x86_64-unknown-illumos.tar.gz) = 9b3ca7d18970d2023f25a82dd8b35c2524e1ba286d3492771a1e1cdf26a4e544d3e42dbad878108e1e52b3617f6e939994a289f4cbd8eaf68c1ddd6a005a1188
-Size (rust-1.81.0-x86_64-unknown-illumos.tar.gz) = 223431240 bytes
-BLAKE2s (rust-1.81.0-x86_64-unknown-linux-gnu.tar.gz) = 64140ced76a7a2230bc710bd2ca562fd3e4c4deb0dff194a71a17a2675911a4c
-SHA512 (rust-1.81.0-x86_64-unknown-linux-gnu.tar.gz) = b6eb16fcb109e6c60a80d63999dce969e7abfed936d6e68c563d212db0cd9ec5d6874d45a185157838878b0ed68e52796d763192656c12496cd7572757292b8c
-Size (rust-1.81.0-x86_64-unknown-linux-gnu.tar.gz) = 340154798 bytes
-BLAKE2s (rust-1.81.0-x86_64-unknown-netbsd.tar.xz) = 74ede561486232e00ddae0119ed776d47d3e8aece14b86bd1510dbd01edd94af
-SHA512 (rust-1.81.0-x86_64-unknown-netbsd.tar.xz) = 05b6274d279a7498143a3632a85201a62bdde1bded70ff24a0b812093eb48758fcfbf27ccde5e65272b27985f24794922d01164c8cf1fdd7f14c674f64f5edd2
-Size (rust-1.81.0-x86_64-unknown-netbsd.tar.xz) = 189273736 bytes
+BLAKE2s (rust-1.82.0-aarch64-apple-darwin.tar.gz) = 664d14f01ccd28193d595f28351d5421e3e28987c6703a7685129386c11b151c
+SHA512 (rust-1.82.0-aarch64-apple-darwin.tar.gz) = 4b25e91e30764c39fcf9efafa96b7a89fe14d64c7364cdc10dd7c9027779f6de73c6f98024df16dc1020b50c404f1201fa3f4c473098f820afada473fa33478e
+Size (rust-1.82.0-aarch64-apple-darwin.tar.gz) = 353239700 bytes
+BLAKE2s (rust-1.82.0-aarch64-unknown-linux-gnu.tar.gz) = 024259d2a3dde28d310fd7ebdda40c324922e1860509c9295df4485b68d40d4e
+SHA512 (rust-1.82.0-aarch64-unknown-linux-gnu.tar.gz) = 5012ed757908ed0db73e0e079a46d4bfce575ea3ebe17a47b127001971944f0d7b885ca28bc7ee8e9da91170106ed434529536e7069c78e3706aacf59d892c15
+Size (rust-1.82.0-aarch64-unknown-linux-gnu.tar.gz) = 501568008 bytes
+BLAKE2s (rust-1.82.0-aarch64-unknown-netbsd.tar.xz) = 3e64188087780dbd2d1816d13542233b0643470a1c8ec0760e333c461810999c
+SHA512 (rust-1.82.0-aarch64-unknown-netbsd.tar.xz) = db70efdbd55f3ed9df5bc197674bbb84dc1193c18bca25cd3326bd0a435dacba9065e8d2f6bc0f733d2f8683cea3e00881231b0af06fbacb43df8b19a1e74160
+Size (rust-1.82.0-aarch64-unknown-netbsd.tar.xz) = 205636040 bytes
+BLAKE2s (rust-1.82.0-aarch64_be-unknown-netbsd.tar.xz) = c97147db08a5c44815bf1c32447c15dff9b22c592dbe7f8474ae7b188309a05a
+SHA512 (rust-1.82.0-aarch64_be-unknown-netbsd.tar.xz) = 5ad6da49ff80a1860dedc0bdb8ac8ff8c975367118db75d0528ee83c10ea7598ac881448a5641d5010b35b34d0aeeb4dfc19ad581ba304fc844947ead09f0d05
+Size (rust-1.82.0-aarch64_be-unknown-netbsd.tar.xz) = 203750380 bytes
+BLAKE2s (rust-1.82.0-arm-unknown-linux-gnueabihf.tar.gz) = 3abbf4f06c99179032861cf074f14ee2fa2ce3e7a20e78a8593f8f1b08d47dbe
+SHA512 (rust-1.82.0-arm-unknown-linux-gnueabihf.tar.gz) = fed91cfba7268b699925174a18d974dd07dc24d6656253c51068103ac063617f29a15e53e4b31c1d61dafcaf1a5ab37234191fb5273ae82fc60767e1bbd4c44d
+Size (rust-1.82.0-arm-unknown-linux-gnueabihf.tar.gz) = 383691956 bytes
+BLAKE2s (rust-1.82.0-armv6-unknown-netbsd-eabihf.tar.xz) = 83784b40300458573a8cea5e37cf700c5c72746b831363ded55aef9b2031ff4f
+SHA512 (rust-1.82.0-armv6-unknown-netbsd-eabihf.tar.xz) = ed77b4948265483362ab1548b98fdd837fffa49e5144d0647c657555f965462f5729b53f2e9fa0655e37c32ba42a7b4398642a76a199e89ae2f8749c0acb88c7
+Size (rust-1.82.0-armv6-unknown-netbsd-eabihf.tar.xz) = 175096484 bytes
+BLAKE2s (rust-1.82.0-armv7-unknown-linux-gnueabihf.tar.gz) = f90488b00b7360fe8e57eb1f66c54924fc08c370244108a0cbebdc6d05aff95b
+SHA512 (rust-1.82.0-armv7-unknown-linux-gnueabihf.tar.gz) = 3d2d090f11f5d3b3125ff0e33776c2addcc999c07406e9d5726eec17e7f874008facd30fe2844b16e8a90ed7b0da44d7ab24ced99fb6a4bf91168edae203740c
+Size (rust-1.82.0-armv7-unknown-linux-gnueabihf.tar.gz) = 371690001 bytes
+BLAKE2s (rust-1.82.0-armv7-unknown-netbsd-eabihf.tar.xz) = a20536546db9e91726dfb3ceeb58d9ae4d54e04c0ba52ccbfeb5f82ef549e857
+SHA512 (rust-1.82.0-armv7-unknown-netbsd-eabihf.tar.xz) = 985c92c2f366162d6960ddb96ac6be15f7d770f9964d96026ac0c55a1939a0be69ee206697db9fb2da0546417aef19bddaddf26d2484db486160517a9d205d0f
+Size (rust-1.82.0-armv7-unknown-netbsd-eabihf.tar.xz) = 175788804 bytes
+BLAKE2s (rust-1.82.0-i586-unknown-netbsd.tar.xz) = dfe4e0008619c899cbfee987db9e15f02346520e710d886806bc74383da95d4b
+SHA512 (rust-1.82.0-i586-unknown-netbsd.tar.xz) = 7024ab15af2f74e91f1d919f51887b6f78c9dbf7c7194b4899df4d459cc0ec42f752864fa27ad2a8920855a5bb5852b71109962795c1ce3327cb8129a55baf20
+Size (rust-1.82.0-i586-unknown-netbsd.tar.xz) = 226751484 bytes
+BLAKE2s (rust-1.82.0-i686-unknown-linux-gnu.tar.gz) = 8e96b3a839e940f069b9f1220792e0d3777e3f77823d840b723b586a5e2039e6
+SHA512 (rust-1.82.0-i686-unknown-linux-gnu.tar.gz) = e8197c5a41c5028bf6ed34891671d8b891a82a1e54815eb1f3833e5d21bc4c12f6c49041d1246336a1417224499daef819a0705dad215aa25b360a5b935c6052
+Size (rust-1.82.0-i686-unknown-linux-gnu.tar.gz) = 453859154 bytes
+BLAKE2s (rust-1.82.0-powerpc-unknown-netbsd.tar.xz) = ab56bfec95efeeb8b95d6c195899bffa7ff0a1569f40e1163170876d087fd6e8
+SHA512 (rust-1.82.0-powerpc-unknown-netbsd.tar.xz) = 0a00ce1d1324b2deb7ae77e9a16e57f178e9f18b0caffc18350f89d1573a4ea44f27641929f6af5dd70daabb1deea58571375b1468fc4651b086b20d772f4de2
+Size (rust-1.82.0-powerpc-unknown-netbsd.tar.xz) = 237715156 bytes
BLAKE2s (rust-1.82.0-riscv64gc-unknown-netbsd.tar.xz) = acb6312c2022c4d2016fed300ba2f861bd98cca4650a66851048aa07c6c999ac
SHA512 (rust-1.82.0-riscv64gc-unknown-netbsd.tar.xz) = 7831912b24f96e6429433f7da223aa7b6232e0329e85770932ce676335945480b691725f40ab472acb4bfbcfe191aff949bf2fe0dcbc58ee9a13feadb470406f
Size (rust-1.82.0-riscv64gc-unknown-netbsd.tar.xz) = 223052688 bytes
-BLAKE2s (rust-std-1.81.0-aarch64-apple-darwin.tar.gz) = 8ed47dcb59bc50d4450ab4d425cc955b58b7829109aaffc397d75ed687bdbcc1
-SHA512 (rust-std-1.81.0-aarch64-apple-darwin.tar.gz) = 39dda9eea3f3f7b1967cc0a8de0b1be13147ba669134fc5ab3cd6780f8a8fb6072dab42dae2a61bc461709d218253257772a8f2520b7f737c6e0964028e90e5a
-Size (rust-std-1.81.0-aarch64-apple-darwin.tar.gz) = 40942716 bytes
-BLAKE2s (rust-std-1.81.0-aarch64-unknown-linux-gnu.tar.gz) = 6577ee264d45ae3fa78e56be44ec2580ce3193e6cbd42546e5ecf2dc844612f6
-SHA512 (rust-std-1.81.0-aarch64-unknown-linux-gnu.tar.gz) = b169c386746ac1af1254fe7bd6dd9c83fb259bb8749ece7db7feb7f2f18e85f84ff2fbec5e4d7721010388a0fa30dc941b4730c90980bba74caee389652ce355
-Size (rust-std-1.81.0-aarch64-unknown-linux-gnu.tar.gz) = 57042816 bytes
-BLAKE2s (rust-std-1.81.0-aarch64-unknown-netbsd.tar.xz) = caf19d678e536fc64865c83612858fcb2bbb92e4df93af7988da660c00d49f22
-SHA512 (rust-std-1.81.0-aarch64-unknown-netbsd.tar.xz) = 27f1da8d2be1d6a93fd126b5dc54063600ff855c97f1f2bf16b2e1e6d7c56f8ce233963b4a6b8707d218a7a6de48a0f184c58bcf9f8f4f2b4a7c097570b6e45f
-Size (rust-std-1.81.0-aarch64-unknown-netbsd.tar.xz) = 23243712 bytes
-BLAKE2s (rust-std-1.81.0-aarch64_be-unknown-netbsd.tar.xz) = 8943bda365466ce352ecdfcbffd62f0307a2ff90916e8f613ac75cfb4d552b44
-SHA512 (rust-std-1.81.0-aarch64_be-unknown-netbsd.tar.xz) = 1a87788b66828b66fb40c8675bfe267bb0cc0dcc817ccb32c6d3f6509717bcca730c5ae424dfdd851ee696316209a00a057532bb138bd2dbdfd04c9bce8d3014
-Size (rust-std-1.81.0-aarch64_be-unknown-netbsd.tar.xz) = 21856844 bytes
-BLAKE2s (rust-std-1.81.0-arm-unknown-linux-gnueabihf.tar.gz) = 07e7b077f156da9c8a9d90abcdf7c77cc0a28299911c2633daa05d1a186a6585
-SHA512 (rust-std-1.81.0-arm-unknown-linux-gnueabihf.tar.gz) = eb91e62805b62f92904f6ee48f237843b210c8b09c9c109ffe17ff466054184ed285427a8ff67e0280c87e26933424060cfc22175185395a4b73d33adc18c088
-Size (rust-std-1.81.0-arm-unknown-linux-gnueabihf.tar.gz) = 37638920 bytes
-BLAKE2s (rust-std-1.81.0-armv6-unknown-netbsd-eabihf.tar.xz) = 753e2af4a71e5658739819e21af09130891b9ef85d33f772b83848dd6d731101
-SHA512 (rust-std-1.81.0-armv6-unknown-netbsd-eabihf.tar.xz) = 26f99382fd36624f7a1e2ad8835d40d669cbd0577a2cbb7f4841f78e115fed1f73d8e6624c8f48590f37b0b6ba9661617e247af7eedf09f77e4fe8e9715c4ee2
-Size (rust-std-1.81.0-armv6-unknown-netbsd-eabihf.tar.xz) = 21899440 bytes
-BLAKE2s (rust-std-1.81.0-armv7-unknown-linux-gnueabihf.tar.gz) = cf3fb73fa3781cbd107bb1136e45fd31c8f7d684377880d569b045cc22c3422a
-SHA512 (rust-std-1.81.0-armv7-unknown-linux-gnueabihf.tar.gz) = ca8b50ab0cc99bc85fdbddbedb7e328d960143a2e26e42ffde71a1f9faca1710116580043874b64856dcb5ffc87c21826dd8f3cdc534d34ff031c65b0a003c9f
-Size (rust-std-1.81.0-armv7-unknown-linux-gnueabihf.tar.gz) = 39178697 bytes
-BLAKE2s (rust-std-1.81.0-armv7-unknown-netbsd-eabihf.tar.xz) = 30d1d2fccac13a96c3c6014d4fa4e446808048ea16d631a3dc092b60f6952c91
-SHA512 (rust-std-1.81.0-armv7-unknown-netbsd-eabihf.tar.xz) = 621798a1294aa084f99fc13aeb5865d72926a55e95773cb9b6a9d5e9842ef287ad0c53af0729d1189b108ef28214d4b119f67fffb6552f23b5d1b68c7a166386
-Size (rust-std-1.81.0-armv7-unknown-netbsd-eabihf.tar.xz) = 22860184 bytes
-BLAKE2s (rust-std-1.81.0-i586-unknown-netbsd.tar.xz) = 35e760c34fb238ce9f2a0383fc5543f9516fbab914050def953d43e8be5b428e
-SHA512 (rust-std-1.81.0-i586-unknown-netbsd.tar.xz) = 0fdb3e2b5b2885686ec130df9133927092cc6f5f44f29255accfecc78f675f8335f0e6610119a7e849a96e7086603cb3fdd09e108af126fa96f1d17fd916d655
-Size (rust-std-1.81.0-i586-unknown-netbsd.tar.xz) = 23867944 bytes
-BLAKE2s (rust-std-1.81.0-i686-unknown-linux-gnu.tar.gz) = 572f9dd807d373b0b66867e13307e3e3de86cbd0b7cd1fefcd2051de3a2e6876
-SHA512 (rust-std-1.81.0-i686-unknown-linux-gnu.tar.gz) = 0119ad7e92654c52629bb0dcf4b7a938bc322e8956772e3420b47eeaedb010168e94b30a048295952506d658f2dcbcc8bfc3e08aeaf1f504d6dbc74b0134f156
-Size (rust-std-1.81.0-i686-unknown-linux-gnu.tar.gz) = 40598854 bytes
-BLAKE2s (rust-std-1.81.0-powerpc-unknown-netbsd.tar.xz) = 50bc72a21c295c22815f3e0d58210de9ee53bea961974d56608db8f5e138f578
-SHA512 (rust-std-1.81.0-powerpc-unknown-netbsd.tar.xz) = 556cff52c2d801eb45b4bca71d6910ed31830bc36f7cb48e292a3628297214283b2095f1a253f34ab027525af912df233da2e6b04122e519a52059884e79d02c
-Size (rust-std-1.81.0-powerpc-unknown-netbsd.tar.xz) = 21941180 bytes
-BLAKE2s (rust-std-1.81.0-sparc64-unknown-netbsd.tar.xz) = b3c072c7298fd4a7f65b977c3337cd53fbbb405adb043203e5c9aab8b198a572
-SHA512 (rust-std-1.81.0-sparc64-unknown-netbsd.tar.xz) = 2c65b5d46775abe785e2c99c3e32155948c7c80fad43f616fa95c6d9ec550acc0c7249e77ea3b3d87b8229793a1b0bc8b2ed548945a19d9ea063693e43272082
-Size (rust-std-1.81.0-sparc64-unknown-netbsd.tar.xz) = 21714816 bytes
-BLAKE2s (rust-std-1.81.0-x86_64-apple-darwin.tar.gz) = e1c6e4b07c89ba1c93cd12755b3af07a20ecb0c966a1743282bbcb2d7ce92d43
-SHA512 (rust-std-1.81.0-x86_64-apple-darwin.tar.gz) = f2ddcd679cba8ed4c14db371a73dbe2ecd03d7a2aaad235ef69cda798c11625c0e63fd39c79fe735db529a03ac0d6f9df34df7cbb6e96acd965c1c37471625aa
-Size (rust-std-1.81.0-x86_64-apple-darwin.tar.gz) = 42635280 bytes
-BLAKE2s (rust-std-1.81.0-x86_64-unknown-freebsd.tar.gz) = 026227ace5af06800bd3bfde717115d4116b7bd8f4a0a4a198f825d145d96d2a
-SHA512 (rust-std-1.81.0-x86_64-unknown-freebsd.tar.gz) = c93f32f59a25183486516d3428da083172f96b1e92f8474630e0c90114c28663b27c8a7bd9f10c5ecf5d5b6bf8e19f355cf6d30ca20be8e75358b4c2e914aa3e
-Size (rust-std-1.81.0-x86_64-unknown-freebsd.tar.gz) = 43610502 bytes
-BLAKE2s (rust-std-1.81.0-x86_64-unknown-linux-gnu.tar.gz) = 5c6c04ed4901779296231a2580a2cfa3486240056c9ec065e54bdc9749f7a633
-SHA512 (rust-std-1.81.0-x86_64-unknown-linux-gnu.tar.gz) = b49036caeae10ec4093e645be07c81001f28369389ba27f776a8636b84be65874a80880740198a7a82fa27e2c66a6db318b65bd5b3fcff6802a14ead19a4a4e1
-Size (rust-std-1.81.0-x86_64-unknown-linux-gnu.tar.gz) = 46105479 bytes
-BLAKE2s (rust-std-1.81.0-x86_64-unknown-netbsd.tar.xz) = 75f018b2373b86569e8413fa755445bf9bb2fab2d8836a71c5e8accca96bf16d
-SHA512 (rust-std-1.81.0-x86_64-unknown-netbsd.tar.xz) = 3fa73320a09c669196f5acd36cd200bdbbdba59947782fc99dfa1ea4e4496ae14c3b39ec142af1ed068d1511536fdb82bac23046343a3b26c6dcfff55c6a9320
-Size (rust-std-1.81.0-x86_64-unknown-netbsd.tar.xz) = 26259400 bytes
+BLAKE2s (rust-1.82.0-sparc64-unknown-netbsd.tar.xz) = 5a1523dbf4b02eb8a51950e821a3c0975569b0a454c5c063ec59e8e019a282a8
+SHA512 (rust-1.82.0-sparc64-unknown-netbsd.tar.xz) = d8a2c349ade804b9fb06f8f98231ca49649289da0142e7a39f6c2893bd140191e65a683b82bfead5cd3a521550ab6893956d179520c006a3c56df4bd865941b0
+Size (rust-1.82.0-sparc64-unknown-netbsd.tar.xz) = 202245792 bytes
+BLAKE2s (rust-1.82.0-x86_64-apple-darwin.tar.gz) = 9bc4f814e48e1f663d586da87bae1f001d4b0ce71c5879c4b206162082d344a5
+SHA512 (rust-1.82.0-x86_64-apple-darwin.tar.gz) = 0ca5079f938c78d199dee1527d0d9d8c5f481daff4db4e31323a5128108b18934bb377be8087cc2b6213b5100fb14e3fc1dfed1a8a6a0a26fca1b57927e39fea
+Size (rust-1.82.0-x86_64-apple-darwin.tar.gz) = 359733549 bytes
+BLAKE2s (rust-1.82.0-x86_64-unknown-freebsd.tar.gz) = 2a5ccc8fb5aa1d5ff1bbfd60a169dbba28ab2e7933aac37484534215ed0d5f53
+SHA512 (rust-1.82.0-x86_64-unknown-freebsd.tar.gz) = 2e97de2e1d0c9d69662cc151becd478d2b0acaaff42443562f518a4191dadabdf0e165f0b9ae1fe90a8c37114377563d9471da2e631ead6a9b1b8583d57da2d0
+Size (rust-1.82.0-x86_64-unknown-freebsd.tar.gz) = 342962316 bytes
+BLAKE2s (rust-1.82.0-x86_64-unknown-illumos.tar.gz) = 60e203f8e321751467e7cd354629980e8c3d31a857b333ac2f061cab0151a357
+SHA512 (rust-1.82.0-x86_64-unknown-illumos.tar.gz) = 138e6cf5eb3a45aa6631924ddafa5812c3eb1d78d11df6ca7f21e592fd4e80e03137897f194bb8063bc6e105e3604e944cc423a74dfa7eaedc45b92e0d0d3ff9
+Size (rust-1.82.0-x86_64-unknown-illumos.tar.gz) = 229164320 bytes
+BLAKE2s (rust-1.82.0-x86_64-unknown-linux-gnu.tar.gz) = 6e7ce2e72a8bc69e9458ea802d18b1de5f0e697be2720eef8bc465051f13bc18
+SHA512 (rust-1.82.0-x86_64-unknown-linux-gnu.tar.gz) = 0fb69cea8b4ebed5a7859f56b308c743ab094bc04d7266651f8a250bcb262f1c45b2ad2b0e2ee5c854ed35208eafd1f7253a495e55860787ba63396ad6a07133
+Size (rust-1.82.0-x86_64-unknown-linux-gnu.tar.gz) = 353103417 bytes
+BLAKE2s (rust-1.82.0-x86_64-unknown-netbsd.tar.xz) = d6f86610002339974b4e97c304d1cf9d43bada0ada0835acf3a23b5f1de0bf0c
+SHA512 (rust-1.82.0-x86_64-unknown-netbsd.tar.xz) = c20e6b1d181680c2dea48ce6e2e88ed5a9173c6807fac952af5049367715d8d410131cb4fc83c609be6d17044aa90cd8bd7f70ff2143579eba7d4783dbac9483
+Size (rust-1.82.0-x86_64-unknown-netbsd.tar.xz) = 197432356 bytes
+BLAKE2s (rust-std-1.82.0-aarch64-apple-darwin.tar.gz) = c8bfd60bac59cd15304d00cf9c2454b248f70a024207f4b7efba1d041aa2555d
+SHA512 (rust-std-1.82.0-aarch64-apple-darwin.tar.gz) = de7970c83ed3933bafb611ecb4498b1bfb97de8e31ab8ebe492e9ba43978b94687ccba04be1bc2afbf2c810c68de0271fc60c9d61f3bf9de2ce2b73d4f45fe4e
+Size (rust-std-1.82.0-aarch64-apple-darwin.tar.gz) = 41561421 bytes
+BLAKE2s (rust-std-1.82.0-aarch64-unknown-linux-gnu.tar.gz) = 8d58a66f3480132a76a4689c3e3b8344da4aa9e7ba434d5702b3e1191555bfc9
+SHA512 (rust-std-1.82.0-aarch64-unknown-linux-gnu.tar.gz) = 78ec9782a91f8d44615dc18a77f7ceafbf2a6d937dd2673c777f985debfb3ab04a33a32355df292f190488aa38b7ef020e91fa5b3201e6e2d958b195aa2f8d17
+Size (rust-std-1.82.0-aarch64-unknown-linux-gnu.tar.gz) = 57410846 bytes
+BLAKE2s (rust-std-1.82.0-aarch64-unknown-netbsd.tar.xz) = e7e61283000aacf30a0b41fad9fb45f8ebc7bee319238176e9713bf39bd06b68
+SHA512 (rust-std-1.82.0-aarch64-unknown-netbsd.tar.xz) = 2712ad49971bb40b6fd930285550b3f4b01ff513e5f309391e1aade852236d010781aa3e016be63443afaf31af610a479e83a9506dc467eb7c5385bcc1612d0e
+Size (rust-std-1.82.0-aarch64-unknown-netbsd.tar.xz) = 23535784 bytes
+BLAKE2s (rust-std-1.82.0-aarch64_be-unknown-netbsd.tar.xz) = 1a53321f8bc0a3d4e619ea9a3bba88c3f96682c5d213ffce4dc14773b6a0152e
+SHA512 (rust-std-1.82.0-aarch64_be-unknown-netbsd.tar.xz) = 259f512754b4287fc70f8cf859ee2d69de662d073a7186c98fb8a425a7a0d56bceee2cb41d7fcdb758c276722e43d7d4af705693ce448b1c22e1eb469e6f181a
+Size (rust-std-1.82.0-aarch64_be-unknown-netbsd.tar.xz) = 22015532 bytes
+BLAKE2s (rust-std-1.82.0-arm-unknown-linux-gnueabihf.tar.gz) = 6c83d958a0b268e6d8e9649ca81ef28310d6549d2e45548cafbf6ea77e8de3b5
+SHA512 (rust-std-1.82.0-arm-unknown-linux-gnueabihf.tar.gz) = 426133498dd697d33ddabdb5438bcedb28525296182601c05004a673f761dbff323d3446a91a91177ccd0c5fba85d041e2c3225f305a8e18cdcbcebca23e2703
+Size (rust-std-1.82.0-arm-unknown-linux-gnueabihf.tar.gz) = 38148526 bytes
+BLAKE2s (rust-std-1.82.0-armv6-unknown-netbsd-eabihf.tar.xz) = e48c400669a1ba0ccfbf733d79bc00ccc2fb019ee155bd441ff6b08b9dd95553
+SHA512 (rust-std-1.82.0-armv6-unknown-netbsd-eabihf.tar.xz) = 9416593ff0022af16bdfd51d648ae400282f550dfb29fc835aad891d9873b0e51de40365c35261c8adae6d8289d7b5950c9879c492d5a23415aace3c349dc507
+Size (rust-std-1.82.0-armv6-unknown-netbsd-eabihf.tar.xz) = 22069460 bytes
+BLAKE2s (rust-std-1.82.0-armv7-unknown-linux-gnueabihf.tar.gz) = 9bd977e5737c39556c9f43597609e8d62bffe800bb9d257ca18fbb95f48943ed
+SHA512 (rust-std-1.82.0-armv7-unknown-linux-gnueabihf.tar.gz) = d69587493e90896e287f5f346a86752fec6b86dae90e70356314fd7bdf527c8d03ca5611d5575c2bdce567c3f084a59bbc6af3f5680296202eb96a11fe1e99c2
+Size (rust-std-1.82.0-armv7-unknown-linux-gnueabihf.tar.gz) = 39688006 bytes
+BLAKE2s (rust-std-1.82.0-armv7-unknown-netbsd-eabihf.tar.xz) = a0db620662cf3ed369e0a31399f50658a26dd11756fa01a412432ac2334b9ed9
+SHA512 (rust-std-1.82.0-armv7-unknown-netbsd-eabihf.tar.xz) = 5b841e555e513d93c83da0298954535e56bbcff85106eb397bb09be2f29f5814d4972bdb9a81d369dcd1ef4c0479247d73cea8dbf565d443daf212352c7b6582
+Size (rust-std-1.82.0-armv7-unknown-netbsd-eabihf.tar.xz) = 22839068 bytes
+BLAKE2s (rust-std-1.82.0-i586-unknown-netbsd.tar.xz) = fd7ff3c9d66cd8b352a78ff71607e0b2739e661286280088cae0b40d4c076f97
+SHA512 (rust-std-1.82.0-i586-unknown-netbsd.tar.xz) = ef62830f4a8f9f66361279a76e8fb36f12fc293e4daae091646122180617f4f464b222d64cdc26ee1be222f97390d1b5bb7cd4d6da4498a451cbee1943b3a34f
+Size (rust-std-1.82.0-i586-unknown-netbsd.tar.xz) = 24696004 bytes
+BLAKE2s (rust-std-1.82.0-i686-unknown-linux-gnu.tar.gz) = a3c3502c46d275c596221a1608527a5df420405afb6093952080fdb28740afa7
+SHA512 (rust-std-1.82.0-i686-unknown-linux-gnu.tar.gz) = 8399c1185b5bae51693f6e9e48b59ec6da8b1dbc2117d61ab17549bead9f016a250f9b431d3b83c52ce0bd656d8a594b748b46c7cab28a24ea9cdc99d13114b9
+Size (rust-std-1.82.0-i686-unknown-linux-gnu.tar.gz) = 42491398 bytes
+BLAKE2s (rust-std-1.82.0-powerpc-unknown-netbsd.tar.xz) = cd52c13769dac50c47136d5de59b310a82ad395d9759fe3389f7eead58f56703
+SHA512 (rust-std-1.82.0-powerpc-unknown-netbsd.tar.xz) = b66d15b3596da911b3e9f73a11b664bdefc266b300783653d6c5354c8d024372e18fec8649dab1e3593fa390aacd607f452cb1c0e453ca35c32b2f0cb4ac58ff
+Size (rust-std-1.82.0-powerpc-unknown-netbsd.tar.xz) = 22306616 bytes
BLAKE2s (rust-std-1.82.0-riscv64gc-unknown-netbsd.tar.xz) = 0ec6d7f55a6f8e37479f5b171232c2d135293b4867da995b3101b9f5bbea1090
SHA512 (rust-std-1.82.0-riscv64gc-unknown-netbsd.tar.xz) = 422ecbc8050ef18c5c16b234937f2ff4c79e30186599f0cbb2ce29aa2e964d8d7611e9f6e2d8aba6791710e4e08c008483e34b22a6538a16d99d461e69ac64c8
Size (rust-std-1.82.0-riscv64gc-unknown-netbsd.tar.xz) = 22154760 bytes
-BLAKE2s (rustc-1.82.0-src.tar.gz) = 5240e949251d8016c35102ab8254d0aba05ff459570ef4097443ff098b417f3d
-SHA512 (rustc-1.82.0-src.tar.gz) = 0a4b4aeffe02fae35bafd64429d15009c23e5f698c0c596c6250c4de6c0dfc4fa7af5b2662c33a6fc511b1f1f2f253e5a6f2967c10ab41347c6a7f1d31bbb303
-Size (rustc-1.82.0-src.tar.gz) = 434309696 bytes
+BLAKE2s (rust-std-1.82.0-sparc64-unknown-netbsd.tar.xz) = 22ab01302cbc81687c1a0058b18f8557d269175331df7a89155cd5a2eec6060d
+SHA512 (rust-std-1.82.0-sparc64-unknown-netbsd.tar.xz) = 22641511f1ae48de29004a738e1c46d51e65a8334399f93b7cba43126190b02988d2426ad603244501d0b2ce0d8fc4a5ca62f50170ae0c7e74c0b72f2fae5c43
+Size (rust-std-1.82.0-sparc64-unknown-netbsd.tar.xz) = 22144860 bytes
+BLAKE2s (rust-std-1.82.0-x86_64-apple-darwin.tar.gz) = cbdfcfa9cb9bad67459fd81fac684de37e421ba3d17c51b645d00e9143f0e740
+SHA512 (rust-std-1.82.0-x86_64-apple-darwin.tar.gz) = 4640294342f0a9842a7c89828ec5eeedf9525c4acf1f2e352b94b91b37094afb72a3553d30285317aefa7c4da3c80bb7ff9839d99165e944b8e749bda1ab0175
+Size (rust-std-1.82.0-x86_64-apple-darwin.tar.gz) = 44709513 bytes
+BLAKE2s (rust-std-1.82.0-x86_64-unknown-freebsd.tar.gz) = 7cad82d6f989c869e90c0d10e1994d4d339ab746f8f4c7ab6af03a79f351287f
+SHA512 (rust-std-1.82.0-x86_64-unknown-freebsd.tar.gz) = 9549f372fe5a9b0a302f79e25ae240fdd23a5da4eb7a09a12a840efa0e36e52f2700173b2eb5b8af808e2d1ed2d5c1d70968e9d6a574d6c362c26e0cc427d75a
+Size (rust-std-1.82.0-x86_64-unknown-freebsd.tar.gz) = 45754523 bytes
+BLAKE2s (rust-std-1.82.0-x86_64-unknown-linux-gnu.tar.gz) = db80214522a2e7c2876423c331d2c9d29335090b164637968aadd506d18a1872
+SHA512 (rust-std-1.82.0-x86_64-unknown-linux-gnu.tar.gz) = de3a0d6abbc27b6f77d1f0c587b4b3b9c8943daf98838224a5855ad99a6d686663aa7f26214a01311c9d5f6818cca03da5fe34122056f9ce01a39de4af2610cc
+Size (rust-std-1.82.0-x86_64-unknown-linux-gnu.tar.gz) = 48253161 bytes
+BLAKE2s (rust-std-1.82.0-x86_64-unknown-netbsd.tar.xz) = d915d3ad213644ac0652ea999c5f42ea17d9ebe3b582b1c15f0fbdf7f95f139d
+SHA512 (rust-std-1.82.0-x86_64-unknown-netbsd.tar.xz) = 9e8307c481bd0c4df57f2c87ef71ab228878d15fbe9011cab157c0c926f7092c8e1e91eb730a6bade98cd99e010e08d5db2b805edd867b371244f8f522f8d771
+Size (rust-std-1.82.0-x86_64-unknown-netbsd.tar.xz) = 27364932 bytes
+BLAKE2s (rustc-1.83.0-src.tar.gz) = 52620e2b07df550604ff94a232230795e561ba90f22ed9b708b432a991c90021
+SHA512 (rustc-1.83.0-src.tar.gz) = 84e5494e4e51a3c885a3155ef3b619923f9ad69bb4196dde6b2e1b11f0d2ef6328a019d1a81a1cb39325730ee1c506c8257936cecc93af1b3d3422838bdc029f
+Size (rustc-1.83.0-src.tar.gz) = 727622101 bytes
SHA1 (patch-compiler_rustc__codegen__ssa_src_back_linker.rs) = f2af6e3b4925e8ca21b7cd783f7831b72700384a
-SHA1 (patch-compiler_rustc__llvm_build.rs) = a4a66d449fc9eb99d648d02a041778a68f4f7ce8
-SHA1 (patch-compiler_rustc__target_src_spec_base_netbsd.rs) = 7d910631f49acf2c33fdd191fd3e0f261efae234
+SHA1 (patch-compiler_rustc__llvm_build.rs) = 3acef995e3038a98b29b31b9bdd43286b1ac29f7
+SHA1 (patch-compiler_rustc__target_src_spec_base_netbsd.rs) = f6805317abaf61fa5e713af0b3599945a93a751a
SHA1 (patch-compiler_rustc__target_src_spec_mod.rs) = a22b5d28997ed9a5565deec9c34322165d563d00
SHA1 (patch-compiler_rustc__target_src_spec_targets_aarch64__be__unknown__netbsd.rs) = 620eaf74c1dd030973af53dfe4f9aa998be5b123
SHA1 (patch-compiler_rustc__target_src_spec_targets_aarch64__unknown__netbsd.rs) = 1a02f2dd61a5f9cc4be1f66ac3404c961810c731
-SHA1 (patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs) = e97b7978cc525db7eadf967d51f4818a3c145754
+SHA1 (patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs) = bbfbac8c4047340fc220e26bfaa8e7d7f5dcb284
SHA1 (patch-compiler_rustc__target_src_spec_targets_mipsel__unknown__netbsd.rs) = 7deeb7d1d3306e96891dec144ac90398b88c6ad4
-SHA1 (patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs) = 847022a9c02d277f39e2c842f23a9ed401bc5534
-SHA1 (patch-config.example.toml) = 520ad7a26249780ae79a5dc1d2b534a8c6aef0a5
+SHA1 (patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs) = cde3a59b5d53b58a3824aef8dddbf815bcdd8eb8
SHA1 (patch-library_backtrace_src_symbolize_gimli.rs) = 9d5ef634c5a454e474ea5fee76da9bb768f5b3d9
SHA1 (patch-library_backtrace_src_symbolize_gimli_elf.rs) = 3b84a462c6bc8245d579452e4c37e3ce13314952
SHA1 (patch-library_std_src_sys_pal_unix_mod.rs) = bfc59ae4568547e3ed71c8b31ba5b5b5363d5d40
SHA1 (patch-library_stdarch_crates_std__detect_tests_cpu-detection.rs) = 97c3ad8ea39c25d41256fcad80fae1e6e4970124
-SHA1 (patch-src_bootstrap_bootstrap.py) = 6f1d3068da49f19c3e092230ba1c7d99af628d3a
+SHA1 (patch-src_bootstrap_bootstrap.py) = 590308748215f7fa386a87aa185f1f5d2dc39323
SHA1 (patch-src_bootstrap_src_core_build__steps_compile.rs) = e928203ed4734c93cc33c5a3f7879cf18dcecc83
-SHA1 (patch-src_bootstrap_src_core_build__steps_dist.rs) = 22e37d6260cbd93ca3c6d119b58e48750836b17c
SHA1 (patch-src_bootstrap_src_core_build__steps_install.rs) = cc6558df42c9c9ac28fdb2ff180bdaa7f22ce816
-SHA1 (patch-src_bootstrap_src_core_builder.rs) = 6d76366201097adc56e494fa05ebbc1696bb2d98
-SHA1 (patch-src_bootstrap_src_core_config_config.rs) = fa9d93602693bce064aa155ad0a204b176b47d99
-SHA1 (patch-src_bootstrap_src_lib.rs) = d29bc3c0b335d5e788eecbb02fc08966beef0fb1
+SHA1 (patch-src_bootstrap_src_core_builder.rs) = 0ff7487718a04080adf6a9631ee2069ace6c3928
+SHA1 (patch-src_bootstrap_src_lib.rs) = 331f14cee4b89d306122c61a68dfc356c872f4f3
SHA1 (patch-src_llvm-project_llvm_CMakeLists.txt) = 7abfabb6ec70df229a69355f8c76825610165c37
SHA1 (patch-src_llvm-project_llvm_cmake_modules_AddLLVM.cmake) = e1b2eb2f0b3cf1cf87b443656ae306b3242f6b12
SHA1 (patch-src_llvm-project_llvm_include_llvm-c_DataTypes.h) = cb011fc19957883c01725797f7c85ed1b20f96f1
SHA1 (patch-src_llvm-project_llvm_include_llvm_Analysis_ConstantFolding.h) = 39d76e6659143d154ae690ac70781b698a2023d8
SHA1 (patch-src_llvm-project_llvm_utils_FileCheck_FileCheck.cpp) = 2587c2f4d11ad8f75bf8a16de625135b26bacc15
SHA1 (patch-src_tools_cargo_src_cargo_core_profiles.rs) = e1af7fde97416e0a269ee34efd37f4f47fcf7a95
-SHA1 (patch-src_tools_cargo_tests_testsuite_build.rs) = 84dfc091a152b83938e8706917d692a329b70393
+SHA1 (patch-src_tools_cargo_tests_testsuite_build.rs) = a7d49360e4c4a082bf640b7d79e3694580d340e4
SHA1 (patch-src_tools_rust-installer_install-template.sh) = 6984546c34a2e4d55a6dbe59baa0d4958184e0b7
+SHA1 (patch-tests_assembly_targets_targets-elf.rs) = 4a3b9ac02905063f56c59a811509d793ec445c85
SHA1 (patch-tools_rust-analyzer_lib_line-index-src_lib.rs) = 4ed527174447ee23fa81dd6840e18b9949d5a273
-SHA1 (patch-vendor_bytecount-0.6.8_src_lib.rs) = d7610f2ae957d085a465f8c75549e5a11586a8b0
-SHA1 (patch-vendor_cc-1.0.73_src_lib.rs) = 690b3feaa619050512254d7c18fd4f51da98e279
+SHA1 (patch-vendor_bytecount-0.6.8_src_lib.rs) = df3641afebac2b06dc9d266524e295c461c441d4
SHA1 (patch-vendor_crossbeam-utils-0.8.18_no__atomic.rs) = d4d9288cb199af9bc7e321fbd2b42860aed954ec
SHA1 (patch-vendor_libc-0.2.155_src_unix_solarish_mod.rs) = 97505b88875aa80fa2b5589b6090237c3786e143
SHA1 (patch-vendor_memchr-2.7.4_src_arch_aarch64_memchr.rs) = 3e17e9f068afe5e812d10bf57fd3f6d4c21baf0b
Index: pkgsrc/lang/rust/options.mk
diff -u pkgsrc/lang/rust/options.mk:1.42 pkgsrc/lang/rust/options.mk:1.43
--- pkgsrc/lang/rust/options.mk:1.42 Sun Nov 24 16:13:43 2024
+++ pkgsrc/lang/rust/options.mk Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-# $NetBSD: options.mk,v 1.42 2024/11/24 16:13:43 he Exp $
+# $NetBSD: options.mk,v 1.43 2025/02/23 08:53:54 he Exp $
PKG_OPTIONS_VAR= PKG_OPTIONS.rust
PKG_SUPPORTED_OPTIONS+= rust-cargo-static rust-docs
@@ -44,13 +44,14 @@ GCC_REQD+= 12
# Use the internal copy of LLVM or the external one?
#
.if empty(PKG_OPTIONS:Mrust-internal-llvm)
+BUILDLINK_API_DEPENDS.llvm+= llvm>=18.0.0
.include "../../lang/libunwind/buildlink3.mk"
.include "../../lang/llvm/buildlink3.mk"
CONFIGURE_ARGS+= --enable-llvm-link-shared
CONFIGURE_ARGS+= --llvm-libunwind=system
CONFIGURE_ARGS+= --llvm-root=${BUILDLINK_PREFIX.llvm}
# Also turn off build of the internal LLD, as the external LLVM
-# may be older (e.g. 17) than the internal LLD (now 18.x), ref.
+# may be older (e.g. 18) than the internal LLD (now 19.x), ref.
# https://github.com/rust-lang/rust/issues/131291
CONFIGURE_ARGS+= --set rust.lld=false
.endif
Index: pkgsrc/lang/rust/platform.mk
diff -u pkgsrc/lang/rust/platform.mk:1.29 pkgsrc/lang/rust/platform.mk:1.30
--- pkgsrc/lang/rust/platform.mk:1.29 Fri Oct 18 08:18:53 2024
+++ pkgsrc/lang/rust/platform.mk Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-# $NetBSD: platform.mk,v 1.29 2024/10/18 08:18:53 abs Exp $
+# $NetBSD: platform.mk,v 1.30 2025/02/23 08:53:54 he Exp $
# This file encodes whether a given platform has support for rust.
@@ -7,24 +7,16 @@
.if !defined(PLATFORM_SUPPORTS_RUST)
-# Rust needs NetBSD>8
-.if empty(OS_VERSION:M[0-8].*)
-. for rust_arch in aarch64 earmv7hf i386 powerpc riscv64 sparc64 x86_64
-RUST_PLATFORMS+= NetBSD-*-${rust_arch}
+# Rust needs NetBSD>=9.0
+# (and really wants the ld.elf_so fixes from later netbsd-9-based releases)
+.for rust_arch in aarch64 earmv7hf i386 powerpc riscv64 sparc64 x86_64
+. for rust_os in Darwin FreeBSD Linux NetBSD SunOS
+. if ${OPSYS} != "NetBSD" || empty(OS_VERSION:M[0-8].*)
+RUST_PLATFORMS+= ${rust_os}-*-${rust_arch}
+. endif
. endfor
-.endif
-
-.for rust_arch in aarch64 earmv7hf i386 x86_64
-RUST_PLATFORMS+= Linux-*-${rust_arch}
.endfor
-.for rust_arch in aarch64 x86_64
-RUST_PLATFORMS+= Darwin-*-${rust_arch}
-.endfor
-
-RUST_PLATFORMS+= FreeBSD-*-x86_64
-RUST_PLATFORMS+= SunOS-*-x86_64
-
.if ${MACHINE_PLATFORM:MNetBSD-*-earm*} && ${OPSYS_VERSION} < 100000
RUST_DIR?= ../../lang/rust176
.endif
Index: pkgsrc/lang/rust/patches/patch-compiler_rustc__llvm_build.rs
diff -u pkgsrc/lang/rust/patches/patch-compiler_rustc__llvm_build.rs:1.17 pkgsrc/lang/rust/patches/patch-compiler_rustc__llvm_build.rs:1.18
--- pkgsrc/lang/rust/patches/patch-compiler_rustc__llvm_build.rs:1.17 Thu Apr 18 09:29:42 2024
+++ pkgsrc/lang/rust/patches/patch-compiler_rustc__llvm_build.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-compiler_rustc__llvm_build.rs,v 1.17 2024/04/18 09:29:42 pin Exp $
+$NetBSD: patch-compiler_rustc__llvm_build.rs,v 1.18 2025/02/23 08:53:54 he Exp $
Fix build on NetBSD HEAD-llvm. XXX there is probably a better way to do this.
@@ -25,9 +25,9 @@ https://github.com/rust-lang/rust/pull/1
// However, LLVM insists on using 64-bit atomics.
// This gives rise to a need to link rust itself with -latomic for these targets
- if target.starts_with("i586") || target.starts_with("i686") {
-+ if target.starts_with("i386")
-+ || target.starts_with("i486")
-+ || target.starts_with("i586")
++ if target.starts_with("i386")
++ || target.starts_with("i486")
++ || target.starts_with("i586")
+ || target.starts_with("i686")
+ {
println!("cargo:rustc-link-lib=atomic");
@@ -38,13 +38,13 @@ https://github.com/rust-lang/rust/pull/1
} else if target.contains("netbsd") && llvm_static_stdcpp.is_some() {
// NetBSD uses a separate library when relocation is required
- "stdc++_p"
-+ if env::var_os("PKGSRC_HAVE_LIBCPP").is_some() {
++ if env::var_os("PKGSRC_HAVE_LIBCPP").is_some() {
+ "c++_pic"
-+ } else {
++ } else {
+ "stdc++_pic"
-+ }
++ }
+ } else if env::var_os("PKGSRC_HAVE_LIBCPP").is_some() {
-+ "c++"
++ "c++"
} else if llvm_use_libcxx.is_some() {
"c++"
} else {
Index: pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_base_netbsd.rs
diff -u pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_base_netbsd.rs:1.3 pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_base_netbsd.rs:1.4
--- pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_base_netbsd.rs:1.3 Mon Jul 15 03:32:23 2024
+++ pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_base_netbsd.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-compiler_rustc__target_src_spec_base_netbsd.rs,v 1.3 2024/07/15 03:32:23 wiz Exp $
+$NetBSD: patch-compiler_rustc__target_src_spec_base_netbsd.rs,v 1.4 2025/02/23 08:53:54 he Exp $
For the benefit of powerpc, when libatomic-links is installed,
search the directory containing the symlinks to -latomic.
@@ -6,10 +6,10 @@ search the directory containing the syml
--- compiler/rustc_target/src/spec/base/netbsd.rs.orig 2024-01-06 19:57:14.887897867 +0000
+++ compiler/rustc_target/src/spec/base/netbsd.rs
@@ -1,12 +1,23 @@
--use crate::spec::{cvs, RelroLevel, TargetOptions};
-+use crate::spec::{cvs, Cc, Lld, RelroLevel, LinkerFlavor, TargetOptions};
+-use crate::spec::{RelroLevel, TargetOptions, cvs};
++use crate::spec::{Cc, Lld, LinkerFlavor, RelroLevel, TargetOptions, cvs};
- pub fn opts() -> TargetOptions {
+ pub(crate) fn opts() -> TargetOptions {
+ let add_linker_paths =
+ &[
+ // For the benefit of powerpc, when libatomic-links is installed,
Index: pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs
diff -u pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs:1.3
pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs:1.4
--- pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs:1.3 Mon Jul 15 03:32:23 2024
+++ pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs,v 1.3 2024/07/15 03:32:23 wiz Exp $
+$NetBSD: patch-compiler_rustc__target_src_spec_targets_mips64el__unknown__netbsd.rs,v 1.4 2025/02/23 08:53:54 he Exp $
Provide a mips64el target with N32, suitable for NetBSD/mips64el.
@@ -8,7 +8,7 @@ Provide a mips64el target with N32, suit
+use crate::abi::Endian;
+use crate::spec::{base, Target, TargetOptions};
+
-+pub fn target() -> Target {
++pub(crate) fn target() -> Target {
+ let mut base = base::netbsd::opts();
+ base.max_atomic_width = Some(32);
+ base.cpu = "mips32".into();
Index: pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs
diff -u pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs:1.1
pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs:1.2
--- pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs:1.1 Wed Jul 31 08:05:50 2024
+++ pkgsrc/lang/rust/patches/patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs,v 1.1 2024/07/31 08:05:50 he Exp $
+$NetBSD: patch-compiler_rustc__target_src_spec_targets_sparc64__unknown__netbsd.rs,v 1.2 2025/02/23 08:53:54 he Exp $
Make more similar to other sparc64 target specs.
@@ -6,10 +6,10 @@ Make more similar to other sparc64 targe
+++ compiler/rustc_target/src/spec/targets/sparc64_unknown_netbsd.rs
@@ -1,11 +1,13 @@
use crate::abi::Endian;
--use crate::spec::{base, Cc, LinkerFlavor, Lld, Target, TargetOptions};
-+use crate::spec::{base, Cc, LinkerFlavor, Lld, Target};
+-use crate::spec::{Cc, LinkerFlavor, Lld, Target, TargetOptions, base};
++use crate::spec::{Cc, LinkerFlavor, Lld, Target, base};
- pub fn target() -> Target {
+ pub(crate) fn target() -> Target {
let mut base = base::netbsd::opts();
base.cpu = "v9".into();
base.add_pre_link_args(LinkerFlavor::Gnu(Cc::Yes, Lld::No), &["-m64"]);
@@ -19,7 +19,7 @@ Make more similar to other sparc64 targe
Target {
llvm_target: "sparc64-unknown-netbsd".into(),
-@@ -18,6 +20,6 @@ pub fn target() -> Target {
+@@ -18,6 +20,6 @@ pub(crate) fn target() -> Target {
pointer_width: 64,
data_layout: "E-m:e-i64:64-n32:64-S128".into(),
arch: "sparc64".into(),
Index: pkgsrc/lang/rust/patches/patch-vendor_bytecount-0.6.8_src_lib.rs
diff -u pkgsrc/lang/rust/patches/patch-vendor_bytecount-0.6.8_src_lib.rs:1.1 pkgsrc/lang/rust/patches/patch-vendor_bytecount-0.6.8_src_lib.rs:1.2
--- pkgsrc/lang/rust/patches/patch-vendor_bytecount-0.6.8_src_lib.rs:1.1 Sun Oct 13 19:04:39 2024
+++ pkgsrc/lang/rust/patches/patch-vendor_bytecount-0.6.8_src_lib.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-vendor_bytecount-0.6.8_src_lib.rs,v 1.1 2024/10/13 19:04:39 he Exp $
+$NetBSD: patch-vendor_bytecount-0.6.8_src_lib.rs,v 1.2 2025/02/23 08:53:54 he Exp $
Avoid using neon on big-endian aarch64.
Ref. https://github.com/rust-lang/rust/issues/129819
@@ -23,7 +23,7 @@ Ref. https://github.com/rust-lang/rust/i
}
- #[cfg(all(target_arch = "aarch64", not(feature = "generic_simd")))]
+ #[cfg(all(
-+ target_arch = "aarch64",
++ target_arch = "aarch64",
+ target_endian = "little",
+ not(feature = "generic_simd")
+ ))]
Index: pkgsrc/lang/rust/patches/patch-src_bootstrap_bootstrap.py
diff -u pkgsrc/lang/rust/patches/patch-src_bootstrap_bootstrap.py:1.24 pkgsrc/lang/rust/patches/patch-src_bootstrap_bootstrap.py:1.25
--- pkgsrc/lang/rust/patches/patch-src_bootstrap_bootstrap.py:1.24 Sun Nov 24 16:13:43 2024
+++ pkgsrc/lang/rust/patches/patch-src_bootstrap_bootstrap.py Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-src_bootstrap_bootstrap.py,v 1.24 2024/11/24 16:13:43 he Exp $
+$NetBSD: patch-src_bootstrap_bootstrap.py,v 1.25 2025/02/23 08:53:54 he Exp $
Use `uname -p` on NetBSD, as that is reliable and sensible there.
Handle earmv[67]hf for NetBSD.
@@ -6,7 +6,7 @@ Also use @PREFIX@ and not $ORIGIN in rpa
--- src/bootstrap/bootstrap.py.orig 2023-07-12 03:32:40.000000000 +0000
+++ src/bootstrap/bootstrap.py
-@@ -270,6 +270,11 @@ def default_build_triple(verbose):
+@@ -286,6 +286,11 @@ def default_build_triple(verbose):
'GNU': 'unknown-hurd',
}
@@ -18,7 +18,7 @@ Also use @PREFIX@ and not $ORIGIN in rpa
# Consider the direct transformation first and then the special cases
if kernel in kerneltype_mapper:
kernel = kerneltype_mapper[kernel]
-@@ -373,10 +378,16 @@ def default_build_triple(verbose):
+@@ -389,10 +394,16 @@ def default_build_triple(verbose):
kernel = 'linux-androideabi'
else:
kernel += 'eabihf'
@@ -36,11 +36,30 @@ Also use @PREFIX@ and not $ORIGIN in rpa
else:
kernel += 'eabihf'
elif cputype == 'mips':
-@@ -734,6 +745,7 @@ class RustBuild(object):
+@@ -623,12 +634,12 @@ class RustBuild(object):
+ print('Choosing a pool size of', pool_size, 'for the unpacking of the tarballs')
+ p = Pool(pool_size)
+ try:
+- # FIXME: A cheap workaround for https://github.com/rust-lang/rust/issues/125578,
+- # remove this once the issue is closed.
+- bootstrap_build_artifacts = os.path.join(self.bootstrap_out(), "debug")
+- if os.path.exists(bootstrap_build_artifacts):
+- shutil.rmtree(bootstrap_build_artifacts)
+-
++# # FIXME: A cheap workaround for https://github.com/rust-lang/rust/issues/125578,
++# # remove this once the issue is closed.
++# bootstrap_build_artifacts = os.path.join(self.bootstrap_out(), "debug")
++# if os.path.exists(bootstrap_build_artifacts):
++# shutil.rmtree(bootstrap_build_artifacts)
++#
+ p.map(unpack_component, tarballs_download_info)
+ finally:
+ p.close()
+@@ -758,6 +769,7 @@ class RustBuild(object):
patchelf = "{}/bin/patchelf".format(nix_deps_dir)
rpath_entries = [
-+ "@PREFIX@/lib",
++ "@PREFIX@/lib",
os.path.join(os.path.realpath(nix_deps_dir), "lib")
]
patchelf_args = ["--add-rpath", ":".join(rpath_entries)]
Index: pkgsrc/lang/rust/patches/patch-src_bootstrap_src_lib.rs
diff -u pkgsrc/lang/rust/patches/patch-src_bootstrap_src_lib.rs:1.2 pkgsrc/lang/rust/patches/patch-src_bootstrap_src_lib.rs:1.3
--- pkgsrc/lang/rust/patches/patch-src_bootstrap_src_lib.rs:1.2 Thu Apr 18 09:29:42 2024
+++ pkgsrc/lang/rust/patches/patch-src_bootstrap_src_lib.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-src_bootstrap_src_lib.rs,v 1.2 2024/04/18 09:29:42 pin Exp $
+$NetBSD: patch-src_bootstrap_src_lib.rs,v 1.3 2025/02/23 08:53:54 he Exp $
Don't filter out optimization flags.
FreeBSD has a particular C++ runtime library name
@@ -16,7 +16,7 @@ FreeBSD has a particular C++ runtime lib
// we want libc++ (more filled out than libstdc++), ensuring that
// LLVM/etc are all properly compiled.
- if matches!(c, CLang::Cxx) && target.contains("apple-darwin") {
-+ if matches!(c, CLang::Cxx) &&
++ if matches!(c, CLang::Cxx) &&
+ (target.contains("apple-darwin") || target.contains("freebsd")) {
base.push("-stdlib=libc++".into());
}
Index: pkgsrc/lang/rust/patches/patch-src_tools_cargo_tests_testsuite_build.rs
diff -u pkgsrc/lang/rust/patches/patch-src_tools_cargo_tests_testsuite_build.rs:1.15 pkgsrc/lang/rust/patches/patch-src_tools_cargo_tests_testsuite_build.rs:1.16
--- pkgsrc/lang/rust/patches/patch-src_tools_cargo_tests_testsuite_build.rs:1.15 Sun Nov 24 16:13:43 2024
+++ pkgsrc/lang/rust/patches/patch-src_tools_cargo_tests_testsuite_build.rs Sun Feb 23 08:53:54 2025
@@ -1,4 +1,4 @@
-$NetBSD: patch-src_tools_cargo_tests_testsuite_build.rs,v 1.15 2024/11/24 16:13:43 he Exp $
+$NetBSD: patch-src_tools_cargo_tests_testsuite_build.rs,v 1.16 2025/02/23 08:53:54 he Exp $
Don't attempt incremental operations on sparc64, ref.
https://sources.debian.org/patches/cargo/0.29.0-1/2007_sparc64_disable_incremental_build.patch/
@@ -26,7 +26,7 @@ https://sources.debian.org/patches/cargo
}
+#[cfg(not(target_arch = "sparc64"))]
- #[allow(deprecated)]
+ #[expect(deprecated)]
#[cargo_test]
fn incremental_profile() {
@@ -176,6 +179,7 @@ fn incremental_profile() {
@@ -34,6 +34,6 @@ https://sources.debian.org/patches/cargo
}
+#[cfg(not(target_arch = "sparc64"))]
- #[allow(deprecated)]
+ #[expect(deprecated)]
#[cargo_test]
fn incremental_config() {
Added files:
Index: pkgsrc/lang/rust/patches/patch-tests_assembly_targets_targets-elf.rs
diff -u /dev/null pkgsrc/lang/rust/patches/patch-tests_assembly_targets_targets-elf.rs:1.1
--- /dev/null Sun Feb 23 08:53:55 2025
+++ pkgsrc/lang/rust/patches/patch-tests_assembly_targets_targets-elf.rs Sun Feb 23 08:53:54 2025
@@ -0,0 +1,16 @@
+$NetBSD: patch-tests_assembly_targets_targets-elf.rs,v 1.1 2025/02/23 08:53:54 he Exp $
+
+Fix make test.
+
+--- tests/assembly/targets/targets-elf.rs.orig 2025-02-04 13:15:03.384854786 +0000
++++ tests/assembly/targets/targets-elf.rs
+@@ -276,6 +276,9 @@
+ //@ revisions: mips64el_unknown_linux_muslabi64
+ //@ [mips64el_unknown_linux_muslabi64] compile-flags: --target mips64el-unknown-linux-muslabi64
+ //@ [mips64el_unknown_linux_muslabi64] needs-llvm-components: mips
++//@ revisions: mips64el_unknown_netbsd
++//@ [mips64el_unknown_netbsd] compile-flags: --target mips64el_unknown_netbsd-unknown-linux-muslabi64
++//@ [mips64el_unknown_netbsd] needs-llvm-components: mips
+ //@ revisions: mips_unknown_linux_gnu
+ //@ [mips_unknown_linux_gnu] compile-flags: --target mips-unknown-linux-gnu
+ //@ [mips_unknown_linux_gnu] needs-llvm-components: mips
Home |
Main Index |
Thread Index |
Old Index
Index: pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_builder.rs
diff -u pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_builder.rs:1.6 pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_builder.rs:1.7
--- pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_builder.rs:1.6 Sun Feb 2 13:34:47 2025
+++ pkgsrc/lang/rust/patches/patch-src_bootstrap_src_core_builder.rs Sun Feb 23 08:53:54 2025
@@ -1,28 +1,51 @@
-$NetBSD: patch-src_bootstrap_src_core_builder.rs,v 1.6 2025/02/02 13:34:47 he Exp $
+$NetBSD: patch-src_bootstrap_src_core_builder.rs,v 1.7 2025/02/23 08:53:54 he Exp $
-Find external libunwind on Linux.
-Use @PREFIX@, not $ORIGIN in rpath.
+Find external libunwind and libLLVM on pkgsrc (not just Linux).
+Use @PREFIX@ in rpath.
---- src/bootstrap/src/core/builder.rs.orig 2006-07-24 01:21:28.000000000 +0000
+Also, follow up on
+https://github.com/rust-lang/rust/issues/133629 by applying
+https://github.com/rust-lang/rust/pull/136309
+which should fix the cross-compile failure.
+
+--- src/bootstrap/src/core/builder.rs.orig 2024-11-26 10:12:09.000000000 +0000
+++ src/bootstrap/src/core/builder.rs
-@@ -2211,6 +2211,11 @@ impl<'a> Builder<'a> {
+@@ -1701,7 +1701,10 @@ impl<'a> Builder<'a> {
+ // Build proc macros both for the host and the target unless proc-macros are not
+ // supported by the target.
+ if target != compiler.host && cmd_kind != Kind::Check {
+- let error = command(self.rustc(compiler))
++ let mut rustc_cmd = command(self.rustc(compiler));
++ self.add_rustc_lib_path(compiler, &mut rustc_cmd);
++
++ let error = rustc_cmd
+ .arg("--target")
+ .arg(target.rustc_target_arg())
+ .arg("--print=file-names")
+@@ -1709,6 +1712,7 @@ impl<'a> Builder<'a> {
+ .arg("-")
+ .run_capture(self)
+ .stderr();
++
+ let not_supported = error
+ .lines()
+ .any(|line| line.contains("unsupported crate type `proc-macro`"));
+@@ -2262,6 +2266,9 @@ impl<'a> Builder<'a> {
rustdocflags.arg("--cfg=parallel_compiler");
}
-+ // added for pkgsrc libunwind
-+ if target.contains("linux") {
-+ rustflags.arg("-Clink-args=-Wl,-rpath,@PREFIX@/lib,-L@PREFIX@/lib");
-+ }
++ // added for pkgsrc libunwind and LLVM
++ rustflags.arg("-Clink-args=-Wl,-rpath,@PREFIX@/lib,-L@PREFIX@/lib");
+
Cargo {
command: cargo,
compiler,
-@@ -2557,7 +2562,7 @@ impl Cargo {
+@@ -2617,7 +2624,7 @@ impl Cargo {
Some(format!("-Wl,-rpath,@loader_path/../{libdir}"))
} else if !target.is_windows() && !target.contains("aix") && !target.contains("xous") {
self.rustflags.arg("-Clink-args=-Wl,-z,origin");
- Some(format!("-Wl,-rpath,$ORIGIN/../{libdir}"))
-+ Some(format!("-Wl,-rpath,@PREFIX@/{libdir}"))
++ Some(format!("-Wl,-rpath,@PREFIX@/lib"))
} else {
None
};